from .resources import *
from .endpoints import *

# Type exports for better discoverability
# Generated type exports
# These types are automatically exported for better IDE support

# Type classes
# DashboardInstanceCallbacksDestinationsCreateBody
# DashboardInstanceCallbacksDestinationsCreateOutput
# DashboardInstanceCallbacksDestinationsDeleteOutput
# DashboardInstanceCallbacksDestinationsGetOutput
# DashboardInstanceCallbacksDestinationsListOutput
# DashboardInstanceCallbacksDestinationsListQuery
# DashboardInstanceCallbacksDestinationsUpdateBody
# DashboardInstanceCallbacksDestinationsUpdateOutput
# DashboardInstanceCallbacksEventsGetOutput
# DashboardInstanceCallbacksEventsListOutput
# DashboardInstanceCallbacksEventsListQuery
# DashboardInstanceCallbacksGetOutput
# DashboardInstanceCallbacksListOutput
# DashboardInstanceCallbacksListQuery
# DashboardInstanceCallbacksNotificationsGetOutput
# DashboardInstanceCallbacksNotificationsListOutput
# DashboardInstanceCallbacksNotificationsListQuery
# DashboardInstanceFilesDeleteOutput
# DashboardInstanceFilesGetOutput
# DashboardInstanceFilesListOutput
# DashboardInstanceFilesListQuery
# DashboardInstanceFilesUpdateBody
# DashboardInstanceFilesUpdateOutput
# DashboardInstanceInstanceGetOutput
# DashboardInstanceLinksCreateBody
# DashboardInstanceLinksCreateOutput
# DashboardInstanceLinksDeleteOutput
# DashboardInstanceLinksGetOutput
# DashboardInstanceLinksListOutput
# DashboardInstanceLinksUpdateBody
# DashboardInstanceLinksUpdateOutput
# DashboardInstanceMagicMcpServersCreateBody
# DashboardInstanceMagicMcpServersCreateOutput
# DashboardInstanceMagicMcpServersDeleteOutput
# DashboardInstanceMagicMcpServersGetOutput
# DashboardInstanceMagicMcpServersListOutput
# DashboardInstanceMagicMcpServersListQuery
# DashboardInstanceMagicMcpServersUpdateBody
# DashboardInstanceMagicMcpServersUpdateOutput
# DashboardInstanceMagicMcpSessionsGetOutput
# DashboardInstanceMagicMcpSessionsListOutput
# DashboardInstanceMagicMcpSessionsListQuery
# DashboardInstanceMagicMcpTokensCreateBody
# DashboardInstanceMagicMcpTokensCreateOutput
# DashboardInstanceMagicMcpTokensDeleteOutput
# DashboardInstanceMagicMcpTokensGetOutput
# DashboardInstanceMagicMcpTokensListOutput
# DashboardInstanceMagicMcpTokensListQuery
# DashboardInstanceMagicMcpTokensUpdateBody
# DashboardInstanceMagicMcpTokensUpdateOutput
# DashboardInstanceProviderOauthConnectionsAuthenticationsGetOutput
# DashboardInstanceProviderOauthConnectionsAuthenticationsListOutput
# DashboardInstanceProviderOauthConnectionsAuthenticationsListQuery
# DashboardInstanceProviderOauthConnectionsCreateBody
# DashboardInstanceProviderOauthConnectionsCreateOutput
# DashboardInstanceProviderOauthConnectionsDeleteOutput
# DashboardInstanceProviderOauthConnectionsGetOutput
# DashboardInstanceProviderOauthConnectionsListOutput
# DashboardInstanceProviderOauthConnectionsListQuery
# DashboardInstanceProviderOauthConnectionsProfilesGetOutput
# DashboardInstanceProviderOauthConnectionsProfilesListOutput
# DashboardInstanceProviderOauthConnectionsProfilesListQuery
# DashboardInstanceProviderOauthConnectionsUpdateBody
# DashboardInstanceProviderOauthConnectionsUpdateOutput
# DashboardInstanceProviderOauthSessionsCreateBody
# DashboardInstanceProviderOauthSessionsCreateOutput
# DashboardInstanceProviderOauthSessionsDeleteOutput
# DashboardInstanceProviderOauthSessionsGetOutput
# DashboardInstanceProviderOauthSessionsListOutput
# DashboardInstanceProviderOauthSessionsListQuery
# DashboardInstanceProviderOauthTakeoutsCreateBody
# DashboardInstanceProviderOauthTakeoutsCreateOutput
# DashboardInstanceProviderOauthTakeoutsGetOutput
# DashboardInstanceProviderOauthTakeoutsListOutput
# DashboardInstanceProviderOauthTakeoutsListQuery
# DashboardInstanceSecretsGetOutput
# DashboardInstanceSecretsListOutput
# DashboardInstanceSecretsListQuery
# DashboardInstanceServerConfigVaultsCreateBody
# DashboardInstanceServerConfigVaultsCreateOutput
# DashboardInstanceServerConfigVaultsGetOutput
# DashboardInstanceServerConfigVaultsListOutput
# DashboardInstanceServerConfigVaultsListQuery
# DashboardInstanceServerConfigVaultsUpdateBody
# DashboardInstanceServerConfigVaultsUpdateOutput
# DashboardInstanceServerRunErrorsGetOutput
# DashboardInstanceServerRunErrorsListOutput
# DashboardInstanceServerRunErrorsListQuery
# DashboardInstanceServerRunsGetOutput
# DashboardInstanceServerRunsListOutput
# DashboardInstanceServerRunsListQuery
# DashboardInstanceServersCapabilitiesListOutput
# DashboardInstanceServersCapabilitiesListQuery
# DashboardInstanceServersDeploymentsCreateBody
# DashboardInstanceServersDeploymentsCreateOutput
# DashboardInstanceServersDeploymentsDeleteOutput
# DashboardInstanceServersDeploymentsGetOutput
# DashboardInstanceServersDeploymentsListOutput
# DashboardInstanceServersDeploymentsListQuery
# DashboardInstanceServersDeploymentsUpdateBody
# DashboardInstanceServersDeploymentsUpdateOutput
# DashboardInstanceServersGetOutput
# DashboardInstanceServersImplementationsCreateBody
# DashboardInstanceServersImplementationsCreateOutput
# DashboardInstanceServersImplementationsDeleteOutput
# DashboardInstanceServersImplementationsGetOutput
# DashboardInstanceServersImplementationsListOutput
# DashboardInstanceServersImplementationsListQuery
# DashboardInstanceServersImplementationsUpdateBody
# DashboardInstanceServersImplementationsUpdateOutput
# DashboardInstanceServersVariantsGetOutput
# DashboardInstanceServersVariantsListOutput
# DashboardInstanceServersVariantsListQuery
# DashboardInstanceServersVersionsGetOutput
# DashboardInstanceServersVersionsListOutput
# DashboardInstanceServersVersionsListQuery
# DashboardInstanceSessionsConnectionsGetOutput
# DashboardInstanceSessionsConnectionsListOutput
# DashboardInstanceSessionsConnectionsListQuery
# DashboardInstanceSessionsCreateBody
# DashboardInstanceSessionsCreateOutput
# DashboardInstanceSessionsDeleteOutput
# DashboardInstanceSessionsGetOutput
# DashboardInstanceSessionsListOutput
# DashboardInstanceSessionsListQuery
# DashboardInstanceSessionsMessagesGetOutput
# DashboardInstanceSessionsMessagesListOutput
# DashboardInstanceSessionsMessagesListQuery
# DashboardOrganizationsTeamsCreateBody
# DashboardOrganizationsTeamsCreateOutput
# DashboardOrganizationsTeamsGetOutput
# DashboardOrganizationsTeamsListOutput
# DashboardOrganizationsTeamsListQuery
# DashboardOrganizationsTeamsMembersCreateBody
# DashboardOrganizationsTeamsMembersCreateOutput
# DashboardOrganizationsTeamsMembersDeleteOutput
# DashboardOrganizationsTeamsPermissionsOutput
# DashboardOrganizationsTeamsProjectsRemoveOutput
# DashboardOrganizationsTeamsProjectsSetBody
# DashboardOrganizationsTeamsProjectsSetOutput
# DashboardOrganizationsTeamsRolesCreateBody
# DashboardOrganizationsTeamsRolesCreateOutput
# DashboardOrganizationsTeamsRolesGetOutput
# DashboardOrganizationsTeamsRolesListOutput
# DashboardOrganizationsTeamsRolesListQuery
# DashboardOrganizationsTeamsRolesUpdateBody
# DashboardOrganizationsTeamsRolesUpdateOutput
# DashboardOrganizationsTeamsUpdateBody
# DashboardOrganizationsTeamsUpdateOutput

# Mapper classes
# mapDashboardInstanceCallbacksDestinationsCreateBody
# mapDashboardInstanceCallbacksDestinationsCreateOutput
# mapDashboardInstanceCallbacksDestinationsDeleteOutput
# mapDashboardInstanceCallbacksDestinationsGetOutput
# mapDashboardInstanceCallbacksDestinationsListOutput
# mapDashboardInstanceCallbacksDestinationsListQuery
# mapDashboardInstanceCallbacksDestinationsUpdateBody
# mapDashboardInstanceCallbacksDestinationsUpdateOutput
# mapDashboardInstanceCallbacksEventsGetOutput
# mapDashboardInstanceCallbacksEventsListOutput
# mapDashboardInstanceCallbacksEventsListQuery
# mapDashboardInstanceCallbacksGetOutput
# mapDashboardInstanceCallbacksListOutput
# mapDashboardInstanceCallbacksListQuery
# mapDashboardInstanceCallbacksNotificationsGetOutput
# mapDashboardInstanceCallbacksNotificationsListOutput
# mapDashboardInstanceCallbacksNotificationsListQuery
# mapDashboardInstanceFilesDeleteOutput
# mapDashboardInstanceFilesGetOutput
# mapDashboardInstanceFilesListOutput
# mapDashboardInstanceFilesListQuery
# mapDashboardInstanceFilesUpdateBody
# mapDashboardInstanceFilesUpdateOutput
# mapDashboardInstanceInstanceGetOutput
# mapDashboardInstanceLinksCreateBody
# mapDashboardInstanceLinksCreateOutput
# mapDashboardInstanceLinksDeleteOutput
# mapDashboardInstanceLinksGetOutput
# mapDashboardInstanceLinksListOutput
# mapDashboardInstanceLinksUpdateBody
# mapDashboardInstanceLinksUpdateOutput
# mapDashboardInstanceMagicMcpServersCreateBody
# mapDashboardInstanceMagicMcpServersCreateOutput
# mapDashboardInstanceMagicMcpServersDeleteOutput
# mapDashboardInstanceMagicMcpServersGetOutput
# mapDashboardInstanceMagicMcpServersListOutput
# mapDashboardInstanceMagicMcpServersListQuery
# mapDashboardInstanceMagicMcpServersUpdateBody
# mapDashboardInstanceMagicMcpServersUpdateOutput
# mapDashboardInstanceMagicMcpSessionsGetOutput
# mapDashboardInstanceMagicMcpSessionsListOutput
# mapDashboardInstanceMagicMcpSessionsListQuery
# mapDashboardInstanceMagicMcpTokensCreateBody
# mapDashboardInstanceMagicMcpTokensCreateOutput
# mapDashboardInstanceMagicMcpTokensDeleteOutput
# mapDashboardInstanceMagicMcpTokensGetOutput
# mapDashboardInstanceMagicMcpTokensListOutput
# mapDashboardInstanceMagicMcpTokensListQuery
# mapDashboardInstanceMagicMcpTokensUpdateBody
# mapDashboardInstanceMagicMcpTokensUpdateOutput
# mapDashboardInstanceProviderOauthConnectionsAuthenticationsGetOutput
# mapDashboardInstanceProviderOauthConnectionsAuthenticationsListOutput
# mapDashboardInstanceProviderOauthConnectionsAuthenticationsListQuery
# mapDashboardInstanceProviderOauthConnectionsCreateBody
# mapDashboardInstanceProviderOauthConnectionsCreateOutput
# mapDashboardInstanceProviderOauthConnectionsDeleteOutput
# mapDashboardInstanceProviderOauthConnectionsGetOutput
# mapDashboardInstanceProviderOauthConnectionsListOutput
# mapDashboardInstanceProviderOauthConnectionsListQuery
# mapDashboardInstanceProviderOauthConnectionsProfilesGetOutput
# mapDashboardInstanceProviderOauthConnectionsProfilesListOutput
# mapDashboardInstanceProviderOauthConnectionsProfilesListQuery
# mapDashboardInstanceProviderOauthConnectionsUpdateBody
# mapDashboardInstanceProviderOauthConnectionsUpdateOutput
# mapDashboardInstanceProviderOauthSessionsCreateBody
# mapDashboardInstanceProviderOauthSessionsCreateOutput
# mapDashboardInstanceProviderOauthSessionsDeleteOutput
# mapDashboardInstanceProviderOauthSessionsGetOutput
# mapDashboardInstanceProviderOauthSessionsListOutput
# mapDashboardInstanceProviderOauthSessionsListQuery
# mapDashboardInstanceProviderOauthTakeoutsCreateBody
# mapDashboardInstanceProviderOauthTakeoutsCreateOutput
# mapDashboardInstanceProviderOauthTakeoutsGetOutput
# mapDashboardInstanceProviderOauthTakeoutsListOutput
# mapDashboardInstanceProviderOauthTakeoutsListQuery
# mapDashboardInstanceSecretsGetOutput
# mapDashboardInstanceSecretsListOutput
# mapDashboardInstanceSecretsListQuery
# mapDashboardInstanceServerConfigVaultsCreateBody
# mapDashboardInstanceServerConfigVaultsCreateOutput
# mapDashboardInstanceServerConfigVaultsGetOutput
# mapDashboardInstanceServerConfigVaultsListOutput
# mapDashboardInstanceServerConfigVaultsListQuery
# mapDashboardInstanceServerConfigVaultsUpdateBody
# mapDashboardInstanceServerConfigVaultsUpdateOutput
# mapDashboardInstanceServerRunErrorsGetOutput
# mapDashboardInstanceServerRunErrorsListOutput
# mapDashboardInstanceServerRunErrorsListQuery
# mapDashboardInstanceServerRunsGetOutput
# mapDashboardInstanceServerRunsListOutput
# mapDashboardInstanceServerRunsListQuery
# mapDashboardInstanceServersCapabilitiesListOutput
# mapDashboardInstanceServersCapabilitiesListQuery
# mapDashboardInstanceServersDeploymentsCreateBody
# mapDashboardInstanceServersDeploymentsCreateOutput
# mapDashboardInstanceServersDeploymentsDeleteOutput
# mapDashboardInstanceServersDeploymentsGetOutput
# mapDashboardInstanceServersDeploymentsListOutput
# mapDashboardInstanceServersDeploymentsListQuery
# mapDashboardInstanceServersDeploymentsUpdateBody
# mapDashboardInstanceServersDeploymentsUpdateOutput
# mapDashboardInstanceServersGetOutput
# mapDashboardInstanceServersImplementationsCreateBody
# mapDashboardInstanceServersImplementationsCreateOutput
# mapDashboardInstanceServersImplementationsDeleteOutput
# mapDashboardInstanceServersImplementationsGetOutput
# mapDashboardInstanceServersImplementationsListOutput
# mapDashboardInstanceServersImplementationsListQuery
# mapDashboardInstanceServersImplementationsUpdateBody
# mapDashboardInstanceServersImplementationsUpdateOutput
# mapDashboardInstanceServersVariantsGetOutput
# mapDashboardInstanceServersVariantsListOutput
# mapDashboardInstanceServersVariantsListQuery
# mapDashboardInstanceServersVersionsGetOutput
# mapDashboardInstanceServersVersionsListOutput
# mapDashboardInstanceServersVersionsListQuery
# mapDashboardInstanceSessionsConnectionsGetOutput
# mapDashboardInstanceSessionsConnectionsListOutput
# mapDashboardInstanceSessionsConnectionsListQuery
# mapDashboardInstanceSessionsCreateBody
# mapDashboardInstanceSessionsCreateOutput
# mapDashboardInstanceSessionsDeleteOutput
# mapDashboardInstanceSessionsGetOutput
# mapDashboardInstanceSessionsListOutput
# mapDashboardInstanceSessionsListQuery
# mapDashboardInstanceSessionsMessagesGetOutput
# mapDashboardInstanceSessionsMessagesListOutput
# mapDashboardInstanceSessionsMessagesListQuery
# mapDashboardOrganizationsTeamsCreateBody
# mapDashboardOrganizationsTeamsCreateOutput
# mapDashboardOrganizationsTeamsGetOutput
# mapDashboardOrganizationsTeamsListOutput
# mapDashboardOrganizationsTeamsListQuery
# mapDashboardOrganizationsTeamsMembersCreateBody
# mapDashboardOrganizationsTeamsMembersCreateOutput
# mapDashboardOrganizationsTeamsMembersDeleteOutput
# mapDashboardOrganizationsTeamsPermissionsOutput
# mapDashboardOrganizationsTeamsProjectsRemoveOutput
# mapDashboardOrganizationsTeamsProjectsSetBody
# mapDashboardOrganizationsTeamsProjectsSetOutput
# mapDashboardOrganizationsTeamsRolesCreateBody
# mapDashboardOrganizationsTeamsRolesCreateOutput
# mapDashboardOrganizationsTeamsRolesGetOutput
# mapDashboardOrganizationsTeamsRolesListOutput
# mapDashboardOrganizationsTeamsRolesListQuery
# mapDashboardOrganizationsTeamsRolesUpdateBody
# mapDashboardOrganizationsTeamsRolesUpdateOutput
# mapDashboardOrganizationsTeamsUpdateBody
# mapDashboardOrganizationsTeamsUpdateOutput

# All types and mappers are available via:
# from .resources import *
# from .endpoints import *
