from .resources import *
from .endpoints import *

# Type exports for better discoverability
# Generated type exports
# These types are automatically exported for better IDE support

# Type classes
# ConsumerProfileGetOutput
# ConsumerProfileGroupsListOutput
# ConsumerProfileGroupsListQuery
# ConsumerProvidersDeployBody
# ConsumerProvidersDeployOutput
# ConsumerProvidersGetOutput
# ConsumerProvidersGetSetupOutput
# ConsumerProvidersListOutput
# ConsumerProvidersListQuery
# ConsumerProvidersRequestAccessBody
# ConsumerProvidersRequestAccessOutput
# ConsumerProvidersSetupBody
# ConsumerProvidersSetupOutput
# ConsumerSessionGetOutput
# ConsumerSessionLogoutOutput
# DashboardInstanceCallbacksCreateBody
# DashboardInstanceCallbacksCreateOutput
# DashboardInstanceCallbacksDeleteOutput
# DashboardInstanceCallbacksDestinationsCreateBody
# DashboardInstanceCallbacksDestinationsCreateOutput
# DashboardInstanceCallbacksDestinationsDeleteOutput
# DashboardInstanceCallbacksDestinationsGetOutput
# DashboardInstanceCallbacksDestinationsListOutput
# DashboardInstanceCallbacksDestinationsListQuery
# DashboardInstanceCallbacksDestinationsUpdateBody
# DashboardInstanceCallbacksDestinationsUpdateOutput
# DashboardInstanceCallbacksEventsGetOutput
# DashboardInstanceCallbacksEventsListOutput
# DashboardInstanceCallbacksEventsListQuery
# DashboardInstanceCallbacksGetOutput
# DashboardInstanceCallbacksInstancesCreateBody
# DashboardInstanceCallbacksInstancesCreateOutput
# DashboardInstanceCallbacksInstancesDeleteOutput
# DashboardInstanceCallbacksInstancesListOutput
# DashboardInstanceCallbacksInstancesListQuery
# DashboardInstanceCallbacksListOutput
# DashboardInstanceCallbacksListQuery
# DashboardInstanceCallbacksNotificationsGetOutput
# DashboardInstanceCallbacksNotificationsListOutput
# DashboardInstanceCallbacksNotificationsListQuery
# DashboardInstanceCallbacksUpdateBody
# DashboardInstanceCallbacksUpdateOutput
# DashboardInstanceCustomProvidersCommitsCreateBody
# DashboardInstanceCustomProvidersCommitsCreateOutput
# DashboardInstanceCustomProvidersCommitsGetOutput
# DashboardInstanceCustomProvidersCommitsListOutput
# DashboardInstanceCustomProvidersCommitsListQuery
# DashboardInstanceCustomProvidersCreateBody
# DashboardInstanceCustomProvidersCreateOutput
# DashboardInstanceCustomProvidersDeploymentsGetLogsOutput
# DashboardInstanceCustomProvidersDeploymentsGetOutput
# DashboardInstanceCustomProvidersDeploymentsListOutput
# DashboardInstanceCustomProvidersDeploymentsListQuery
# DashboardInstanceCustomProvidersEnvironmentsGetOutput
# DashboardInstanceCustomProvidersEnvironmentsListOutput
# DashboardInstanceCustomProvidersEnvironmentsListQuery
# DashboardInstanceCustomProvidersGetOutput
# DashboardInstanceCustomProvidersListOutput
# DashboardInstanceCustomProvidersListQuery
# DashboardInstanceCustomProvidersUpdateBody
# DashboardInstanceCustomProvidersUpdateOutput
# DashboardInstanceCustomProvidersVersionsCreateBody
# DashboardInstanceCustomProvidersVersionsCreateOutput
# DashboardInstanceCustomProvidersVersionsGetOutput
# DashboardInstanceCustomProvidersVersionsListOutput
# DashboardInstanceCustomProvidersVersionsListQuery
# DashboardInstanceFileLinksCreateBody
# DashboardInstanceFileLinksCreateOutput
# DashboardInstanceFileLinksDeleteOutput
# DashboardInstanceFileLinksGetOutput
# DashboardInstanceFileLinksListOutput
# DashboardInstanceFileLinksListQuery
# DashboardInstanceFilesDeleteOutput
# DashboardInstanceFilesGetOutput
# DashboardInstanceFilesListOutput
# DashboardInstanceFilesListQuery
# DashboardInstanceIdentitiesCreateBody
# DashboardInstanceIdentitiesCreateOutput
# DashboardInstanceIdentitiesCredentialsCreateBody
# DashboardInstanceIdentitiesCredentialsCreateOutput
# DashboardInstanceIdentitiesCredentialsDeleteOutput
# DashboardInstanceIdentitiesCredentialsGetOutput
# DashboardInstanceIdentitiesCredentialsListOutput
# DashboardInstanceIdentitiesCredentialsListQuery
# DashboardInstanceIdentitiesCredentialsUpdateBody
# DashboardInstanceIdentitiesCredentialsUpdateOutput
# DashboardInstanceIdentitiesDelegationConfigsCreateBody
# DashboardInstanceIdentitiesDelegationConfigsCreateOutput
# DashboardInstanceIdentitiesDelegationConfigsDeleteOutput
# DashboardInstanceIdentitiesDelegationConfigsGetOutput
# DashboardInstanceIdentitiesDelegationConfigsListOutput
# DashboardInstanceIdentitiesDelegationConfigsListQuery
# DashboardInstanceIdentitiesDelegationConfigsUpdateBody
# DashboardInstanceIdentitiesDelegationConfigsUpdateOutput
# DashboardInstanceIdentitiesDelegationRequestsApproveOutput
# DashboardInstanceIdentitiesDelegationRequestsApproveQuery
# DashboardInstanceIdentitiesDelegationRequestsCreateBody
# DashboardInstanceIdentitiesDelegationRequestsCreateOutput
# DashboardInstanceIdentitiesDelegationRequestsDenyOutput
# DashboardInstanceIdentitiesDelegationRequestsDenyQuery
# DashboardInstanceIdentitiesDelegationRequestsGetOutput
# DashboardInstanceIdentitiesDelegationRequestsGetQuery
# DashboardInstanceIdentitiesDelegationRequestsListOutput
# DashboardInstanceIdentitiesDelegationRequestsListQuery
# DashboardInstanceIdentitiesDelegationsCreateBody
# DashboardInstanceIdentitiesDelegationsCreateOutput
# DashboardInstanceIdentitiesDelegationsGetOutput
# DashboardInstanceIdentitiesDelegationsListOutput
# DashboardInstanceIdentitiesDelegationsListQuery
# DashboardInstanceIdentitiesDelegationsRevokeOutput
# DashboardInstanceIdentitiesDeleteOutput
# DashboardInstanceIdentitiesGetOutput
# DashboardInstanceIdentitiesListOutput
# DashboardInstanceIdentitiesListQuery
# DashboardInstanceIdentitiesUpdateBody
# DashboardInstanceIdentitiesUpdateOutput
# DashboardInstanceIdentityActorsCreateBody
# DashboardInstanceIdentityActorsCreateOutput
# DashboardInstanceIdentityActorsDeleteOutput
# DashboardInstanceIdentityActorsGetOutput
# DashboardInstanceIdentityActorsListOutput
# DashboardInstanceIdentityActorsListQuery
# DashboardInstanceIdentityActorsUpdateBody
# DashboardInstanceIdentityActorsUpdateOutput
# DashboardInstanceInstanceGetOutput
# DashboardInstanceMagicMcpGroupsAddServersBody
# DashboardInstanceMagicMcpGroupsAddServersOutput
# DashboardInstanceMagicMcpGroupsCreateBody
# DashboardInstanceMagicMcpGroupsCreateOutput
# DashboardInstanceMagicMcpGroupsDeleteOutput
# DashboardInstanceMagicMcpGroupsGetOutput
# DashboardInstanceMagicMcpGroupsListOutput
# DashboardInstanceMagicMcpGroupsListQuery
# DashboardInstanceMagicMcpGroupsRemoveServersBody
# DashboardInstanceMagicMcpGroupsRemoveServersOutput
# DashboardInstanceMagicMcpGroupsUpdateBody
# DashboardInstanceMagicMcpGroupsUpdateOutput
# DashboardInstanceMagicMcpServersCreateBody
# DashboardInstanceMagicMcpServersCreateOutput
# DashboardInstanceMagicMcpServersDeleteOutput
# DashboardInstanceMagicMcpServersGetOutput
# DashboardInstanceMagicMcpServersListOutput
# DashboardInstanceMagicMcpServersListQuery
# DashboardInstanceMagicMcpServersUpdateBody
# DashboardInstanceMagicMcpServersUpdateOutput
# DashboardInstanceMagicMcpSessionsGetOutput
# DashboardInstanceMagicMcpSessionsListOutput
# DashboardInstanceMagicMcpSessionsListQuery
# DashboardInstanceMagicMcpTokensAddGroupsBody
# DashboardInstanceMagicMcpTokensAddGroupsOutput
# DashboardInstanceMagicMcpTokensCreateBody
# DashboardInstanceMagicMcpTokensCreateOutput
# DashboardInstanceMagicMcpTokensDeleteOutput
# DashboardInstanceMagicMcpTokensGetOutput
# DashboardInstanceMagicMcpTokensListOutput
# DashboardInstanceMagicMcpTokensListQuery
# DashboardInstanceMagicMcpTokensRemoveGroupsBody
# DashboardInstanceMagicMcpTokensRemoveGroupsOutput
# DashboardInstanceMagicMcpTokensUpdateBody
# DashboardInstanceMagicMcpTokensUpdateOutput
# DashboardInstancePortalsCreateBody
# DashboardInstancePortalsCreateOutput
# DashboardInstancePortalsDeleteOutput
# DashboardInstancePortalsGetOutput
# DashboardInstancePortalsListOutput
# DashboardInstancePortalsListQuery
# DashboardInstancePortalsUpdateBody
# DashboardInstancePortalsUpdateOutput
# DashboardInstanceProviderCategoriesGetOutput
# DashboardInstanceProviderCategoriesListOutput
# DashboardInstanceProviderCategoriesListQuery
# DashboardInstanceProviderCollectionsGetOutput
# DashboardInstanceProviderCollectionsListOutput
# DashboardInstanceProviderCollectionsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsCreateBody
# DashboardInstanceProviderDeploymentsAuthConfigsCreateOutput
# DashboardInstanceProviderDeploymentsAuthConfigsDeleteOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsCreateBody
# DashboardInstanceProviderDeploymentsAuthConfigsExportsCreateOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsGetOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsListOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsGetOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsCreateBody
# DashboardInstanceProviderDeploymentsAuthConfigsImportsCreateOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsGetOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaQuery
# DashboardInstanceProviderDeploymentsAuthConfigsImportsListOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsListOutput
# DashboardInstanceProviderDeploymentsAuthConfigsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsUpdateBody
# DashboardInstanceProviderDeploymentsAuthConfigsUpdateOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsCreateBody
# DashboardInstanceProviderDeploymentsAuthCredentialsCreateOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsDeleteOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsGetOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsListOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsListQuery
# DashboardInstanceProviderDeploymentsAuthCredentialsUpdateBody
# DashboardInstanceProviderDeploymentsAuthCredentialsUpdateOutput
# DashboardInstanceProviderDeploymentsConfigVaultsCreateBody
# DashboardInstanceProviderDeploymentsConfigVaultsCreateOutput
# DashboardInstanceProviderDeploymentsConfigVaultsDeleteOutput
# DashboardInstanceProviderDeploymentsConfigVaultsGetOutput
# DashboardInstanceProviderDeploymentsConfigVaultsListOutput
# DashboardInstanceProviderDeploymentsConfigVaultsListQuery
# DashboardInstanceProviderDeploymentsConfigVaultsUpdateBody
# DashboardInstanceProviderDeploymentsConfigVaultsUpdateOutput
# DashboardInstanceProviderDeploymentsConfigsCreateBody
# DashboardInstanceProviderDeploymentsConfigsCreateOutput
# DashboardInstanceProviderDeploymentsConfigsDeleteOutput
# DashboardInstanceProviderDeploymentsConfigsGetConfigSchemaOutput
# DashboardInstanceProviderDeploymentsConfigsGetConfigSchemaQuery
# DashboardInstanceProviderDeploymentsConfigsGetOutput
# DashboardInstanceProviderDeploymentsConfigsListOutput
# DashboardInstanceProviderDeploymentsConfigsListQuery
# DashboardInstanceProviderDeploymentsConfigsUpdateBody
# DashboardInstanceProviderDeploymentsConfigsUpdateOutput
# DashboardInstanceProviderDeploymentsCreateBody
# DashboardInstanceProviderDeploymentsCreateOutput
# DashboardInstanceProviderDeploymentsDeleteOutput
# DashboardInstanceProviderDeploymentsGetOutput
# DashboardInstanceProviderDeploymentsListOutput
# DashboardInstanceProviderDeploymentsListQuery
# DashboardInstanceProviderDeploymentsSetupSessionsCreateBody
# DashboardInstanceProviderDeploymentsSetupSessionsCreateOutput
# DashboardInstanceProviderDeploymentsSetupSessionsDeleteOutput
# DashboardInstanceProviderDeploymentsSetupSessionsGetOutput
# DashboardInstanceProviderDeploymentsSetupSessionsListOutput
# DashboardInstanceProviderDeploymentsSetupSessionsListQuery
# DashboardInstanceProviderDeploymentsSetupSessionsUpdateBody
# DashboardInstanceProviderDeploymentsSetupSessionsUpdateOutput
# DashboardInstanceProviderDeploymentsUpdateBody
# DashboardInstanceProviderDeploymentsUpdateOutput
# DashboardInstanceProviderGroupsAddListingBody
# DashboardInstanceProviderGroupsAddListingOutput
# DashboardInstanceProviderGroupsCreateBody
# DashboardInstanceProviderGroupsCreateOutput
# DashboardInstanceProviderGroupsGetOutput
# DashboardInstanceProviderGroupsListOutput
# DashboardInstanceProviderGroupsListQuery
# DashboardInstanceProviderGroupsRemoveListingOutput
# DashboardInstanceProviderGroupsUpdateBody
# DashboardInstanceProviderGroupsUpdateOutput
# DashboardInstanceProviderListingsGetOutput
# DashboardInstanceProviderListingsListOutput
# DashboardInstanceProviderListingsListQuery
# DashboardInstanceProviderRunsGetLogsOutput
# DashboardInstanceProviderRunsGetOutput
# DashboardInstanceProviderRunsListOutput
# DashboardInstanceProviderRunsListQuery
# DashboardInstanceProviderTemplatesCreateBody
# DashboardInstanceProviderTemplatesCreateOutput
# DashboardInstanceProviderTemplatesDeleteOutput
# DashboardInstanceProviderTemplatesGetOutput
# DashboardInstanceProviderTemplatesListOutput
# DashboardInstanceProviderTemplatesListQuery
# DashboardInstanceProviderTemplatesUpdateBody
# DashboardInstanceProviderTemplatesUpdateOutput
# DashboardInstanceProvidersAuthMethodsGetOutput
# DashboardInstanceProvidersAuthMethodsListOutput
# DashboardInstanceProvidersAuthMethodsListQuery
# DashboardInstanceProvidersGetOutput
# DashboardInstanceProvidersListOutput
# DashboardInstanceProvidersListQuery
# DashboardInstanceProvidersSpecificationsGetOutput
# DashboardInstanceProvidersSpecificationsListOutput
# DashboardInstanceProvidersSpecificationsListQuery
# DashboardInstanceProvidersToolsGetOutput
# DashboardInstanceProvidersToolsListOutput
# DashboardInstanceProvidersToolsListQuery
# DashboardInstanceProvidersTriggersGetOutput
# DashboardInstanceProvidersTriggersListOutput
# DashboardInstanceProvidersTriggersListQuery
# DashboardInstanceProvidersVersionsGetOutput
# DashboardInstanceProvidersVersionsListOutput
# DashboardInstanceProvidersVersionsListQuery
# DashboardInstancePublishersGetOutput
# DashboardInstancePublishersListOutput
# DashboardInstancePublishersListQuery
# DashboardInstanceSessionTemplatesCreateBody
# DashboardInstanceSessionTemplatesCreateOutput
# DashboardInstanceSessionTemplatesGetOutput
# DashboardInstanceSessionTemplatesListOutput
# DashboardInstanceSessionTemplatesListQuery
# DashboardInstanceSessionTemplatesProvidersCreateBody
# DashboardInstanceSessionTemplatesProvidersCreateOutput
# DashboardInstanceSessionTemplatesProvidersDeleteOutput
# DashboardInstanceSessionTemplatesProvidersGetOutput
# DashboardInstanceSessionTemplatesProvidersListOutput
# DashboardInstanceSessionTemplatesProvidersListQuery
# DashboardInstanceSessionTemplatesProvidersUpdateBody
# DashboardInstanceSessionTemplatesProvidersUpdateOutput
# DashboardInstanceSessionTemplatesUpdateBody
# DashboardInstanceSessionTemplatesUpdateOutput
# DashboardInstanceSessionsConnectionsGetOutput
# DashboardInstanceSessionsConnectionsListOutput
# DashboardInstanceSessionsConnectionsListQuery
# DashboardInstanceSessionsCreateBody
# DashboardInstanceSessionsCreateOutput
# DashboardInstanceSessionsErrorGroupsGetOutput
# DashboardInstanceSessionsErrorGroupsListOutput
# DashboardInstanceSessionsErrorGroupsListQuery
# DashboardInstanceSessionsErrorsGetOutput
# DashboardInstanceSessionsErrorsListOutput
# DashboardInstanceSessionsErrorsListQuery
# DashboardInstanceSessionsEventsGetOutput
# DashboardInstanceSessionsEventsListOutput
# DashboardInstanceSessionsEventsListQuery
# DashboardInstanceSessionsGetOutput
# DashboardInstanceSessionsListOutput
# DashboardInstanceSessionsListQuery
# DashboardInstanceSessionsMessagesGetOutput
# DashboardInstanceSessionsMessagesListOutput
# DashboardInstanceSessionsMessagesListQuery
# DashboardInstanceSessionsParticipantsGetOutput
# DashboardInstanceSessionsParticipantsListOutput
# DashboardInstanceSessionsParticipantsListQuery
# DashboardInstanceSessionsProvidersCreateBody
# DashboardInstanceSessionsProvidersCreateOutput
# DashboardInstanceSessionsProvidersDeleteOutput
# DashboardInstanceSessionsProvidersGetOutput
# DashboardInstanceSessionsProvidersListOutput
# DashboardInstanceSessionsProvidersListQuery
# DashboardInstanceSessionsProvidersUpdateBody
# DashboardInstanceSessionsProvidersUpdateOutput
# DashboardInstanceSessionsUpdateBody
# DashboardInstanceSessionsUpdateOutput
# DashboardInstanceToolCallsCreateBody
# DashboardInstanceToolCallsCreateOutput
# DashboardInstanceToolCallsGetOutput
# DashboardInstanceToolCallsListOutput
# DashboardInstanceToolCallsListQuery
# InstancesGetOutput
# InstancesListOutput
# TokenGetOutput

# Mapper classes
# mapConsumerProfileGetOutput
# mapConsumerProfileGroupsListOutput
# mapConsumerProfileGroupsListQuery
# mapConsumerProvidersDeployBody
# mapConsumerProvidersDeployOutput
# mapConsumerProvidersGetOutput
# mapConsumerProvidersGetSetupOutput
# mapConsumerProvidersListOutput
# mapConsumerProvidersListQuery
# mapConsumerProvidersRequestAccessBody
# mapConsumerProvidersRequestAccessOutput
# mapConsumerProvidersSetupBody
# mapConsumerProvidersSetupOutput
# mapConsumerSessionGetOutput
# mapConsumerSessionLogoutOutput
# mapDashboardInstanceCallbacksCreateBody
# mapDashboardInstanceCallbacksCreateOutput
# mapDashboardInstanceCallbacksDeleteOutput
# mapDashboardInstanceCallbacksDestinationsCreateBody
# mapDashboardInstanceCallbacksDestinationsCreateOutput
# mapDashboardInstanceCallbacksDestinationsDeleteOutput
# mapDashboardInstanceCallbacksDestinationsGetOutput
# mapDashboardInstanceCallbacksDestinationsListOutput
# mapDashboardInstanceCallbacksDestinationsListQuery
# mapDashboardInstanceCallbacksDestinationsUpdateBody
# mapDashboardInstanceCallbacksDestinationsUpdateOutput
# mapDashboardInstanceCallbacksEventsGetOutput
# mapDashboardInstanceCallbacksEventsListOutput
# mapDashboardInstanceCallbacksEventsListQuery
# mapDashboardInstanceCallbacksGetOutput
# mapDashboardInstanceCallbacksInstancesCreateBody
# mapDashboardInstanceCallbacksInstancesCreateOutput
# mapDashboardInstanceCallbacksInstancesDeleteOutput
# mapDashboardInstanceCallbacksInstancesListOutput
# mapDashboardInstanceCallbacksInstancesListQuery
# mapDashboardInstanceCallbacksListOutput
# mapDashboardInstanceCallbacksListQuery
# mapDashboardInstanceCallbacksNotificationsGetOutput
# mapDashboardInstanceCallbacksNotificationsListOutput
# mapDashboardInstanceCallbacksNotificationsListQuery
# mapDashboardInstanceCallbacksUpdateBody
# mapDashboardInstanceCallbacksUpdateOutput
# mapDashboardInstanceCustomProvidersCommitsCreateBody
# mapDashboardInstanceCustomProvidersCommitsCreateOutput
# mapDashboardInstanceCustomProvidersCommitsGetOutput
# mapDashboardInstanceCustomProvidersCommitsListOutput
# mapDashboardInstanceCustomProvidersCommitsListQuery
# mapDashboardInstanceCustomProvidersCreateBody
# mapDashboardInstanceCustomProvidersCreateOutput
# mapDashboardInstanceCustomProvidersDeploymentsGetLogsOutput
# mapDashboardInstanceCustomProvidersDeploymentsGetOutput
# mapDashboardInstanceCustomProvidersDeploymentsListOutput
# mapDashboardInstanceCustomProvidersDeploymentsListQuery
# mapDashboardInstanceCustomProvidersEnvironmentsGetOutput
# mapDashboardInstanceCustomProvidersEnvironmentsListOutput
# mapDashboardInstanceCustomProvidersEnvironmentsListQuery
# mapDashboardInstanceCustomProvidersGetOutput
# mapDashboardInstanceCustomProvidersListOutput
# mapDashboardInstanceCustomProvidersListQuery
# mapDashboardInstanceCustomProvidersUpdateBody
# mapDashboardInstanceCustomProvidersUpdateOutput
# mapDashboardInstanceCustomProvidersVersionsCreateBody
# mapDashboardInstanceCustomProvidersVersionsCreateOutput
# mapDashboardInstanceCustomProvidersVersionsGetOutput
# mapDashboardInstanceCustomProvidersVersionsListOutput
# mapDashboardInstanceCustomProvidersVersionsListQuery
# mapDashboardInstanceFileLinksCreateBody
# mapDashboardInstanceFileLinksCreateOutput
# mapDashboardInstanceFileLinksDeleteOutput
# mapDashboardInstanceFileLinksGetOutput
# mapDashboardInstanceFileLinksListOutput
# mapDashboardInstanceFileLinksListQuery
# mapDashboardInstanceFilesDeleteOutput
# mapDashboardInstanceFilesGetOutput
# mapDashboardInstanceFilesListOutput
# mapDashboardInstanceFilesListQuery
# mapDashboardInstanceIdentitiesCreateBody
# mapDashboardInstanceIdentitiesCreateOutput
# mapDashboardInstanceIdentitiesCredentialsCreateBody
# mapDashboardInstanceIdentitiesCredentialsCreateOutput
# mapDashboardInstanceIdentitiesCredentialsDeleteOutput
# mapDashboardInstanceIdentitiesCredentialsGetOutput
# mapDashboardInstanceIdentitiesCredentialsListOutput
# mapDashboardInstanceIdentitiesCredentialsListQuery
# mapDashboardInstanceIdentitiesCredentialsUpdateBody
# mapDashboardInstanceIdentitiesCredentialsUpdateOutput
# mapDashboardInstanceIdentitiesDelegationConfigsCreateBody
# mapDashboardInstanceIdentitiesDelegationConfigsCreateOutput
# mapDashboardInstanceIdentitiesDelegationConfigsDeleteOutput
# mapDashboardInstanceIdentitiesDelegationConfigsGetOutput
# mapDashboardInstanceIdentitiesDelegationConfigsListOutput
# mapDashboardInstanceIdentitiesDelegationConfigsListQuery
# mapDashboardInstanceIdentitiesDelegationConfigsUpdateBody
# mapDashboardInstanceIdentitiesDelegationConfigsUpdateOutput
# mapDashboardInstanceIdentitiesDelegationRequestsApproveOutput
# mapDashboardInstanceIdentitiesDelegationRequestsApproveQuery
# mapDashboardInstanceIdentitiesDelegationRequestsCreateBody
# mapDashboardInstanceIdentitiesDelegationRequestsCreateOutput
# mapDashboardInstanceIdentitiesDelegationRequestsDenyOutput
# mapDashboardInstanceIdentitiesDelegationRequestsDenyQuery
# mapDashboardInstanceIdentitiesDelegationRequestsGetOutput
# mapDashboardInstanceIdentitiesDelegationRequestsGetQuery
# mapDashboardInstanceIdentitiesDelegationRequestsListOutput
# mapDashboardInstanceIdentitiesDelegationRequestsListQuery
# mapDashboardInstanceIdentitiesDelegationsCreateBody
# mapDashboardInstanceIdentitiesDelegationsCreateOutput
# mapDashboardInstanceIdentitiesDelegationsGetOutput
# mapDashboardInstanceIdentitiesDelegationsListOutput
# mapDashboardInstanceIdentitiesDelegationsListQuery
# mapDashboardInstanceIdentitiesDelegationsRevokeOutput
# mapDashboardInstanceIdentitiesDeleteOutput
# mapDashboardInstanceIdentitiesGetOutput
# mapDashboardInstanceIdentitiesListOutput
# mapDashboardInstanceIdentitiesListQuery
# mapDashboardInstanceIdentitiesUpdateBody
# mapDashboardInstanceIdentitiesUpdateOutput
# mapDashboardInstanceIdentityActorsCreateBody
# mapDashboardInstanceIdentityActorsCreateOutput
# mapDashboardInstanceIdentityActorsDeleteOutput
# mapDashboardInstanceIdentityActorsGetOutput
# mapDashboardInstanceIdentityActorsListOutput
# mapDashboardInstanceIdentityActorsListQuery
# mapDashboardInstanceIdentityActorsUpdateBody
# mapDashboardInstanceIdentityActorsUpdateOutput
# mapDashboardInstanceInstanceGetOutput
# mapDashboardInstanceMagicMcpGroupsAddServersBody
# mapDashboardInstanceMagicMcpGroupsAddServersOutput
# mapDashboardInstanceMagicMcpGroupsCreateBody
# mapDashboardInstanceMagicMcpGroupsCreateOutput
# mapDashboardInstanceMagicMcpGroupsDeleteOutput
# mapDashboardInstanceMagicMcpGroupsGetOutput
# mapDashboardInstanceMagicMcpGroupsListOutput
# mapDashboardInstanceMagicMcpGroupsListQuery
# mapDashboardInstanceMagicMcpGroupsRemoveServersBody
# mapDashboardInstanceMagicMcpGroupsRemoveServersOutput
# mapDashboardInstanceMagicMcpGroupsUpdateBody
# mapDashboardInstanceMagicMcpGroupsUpdateOutput
# mapDashboardInstanceMagicMcpServersCreateBody
# mapDashboardInstanceMagicMcpServersCreateOutput
# mapDashboardInstanceMagicMcpServersDeleteOutput
# mapDashboardInstanceMagicMcpServersGetOutput
# mapDashboardInstanceMagicMcpServersListOutput
# mapDashboardInstanceMagicMcpServersListQuery
# mapDashboardInstanceMagicMcpServersUpdateBody
# mapDashboardInstanceMagicMcpServersUpdateOutput
# mapDashboardInstanceMagicMcpSessionsGetOutput
# mapDashboardInstanceMagicMcpSessionsListOutput
# mapDashboardInstanceMagicMcpSessionsListQuery
# mapDashboardInstanceMagicMcpTokensAddGroupsBody
# mapDashboardInstanceMagicMcpTokensAddGroupsOutput
# mapDashboardInstanceMagicMcpTokensCreateBody
# mapDashboardInstanceMagicMcpTokensCreateOutput
# mapDashboardInstanceMagicMcpTokensDeleteOutput
# mapDashboardInstanceMagicMcpTokensGetOutput
# mapDashboardInstanceMagicMcpTokensListOutput
# mapDashboardInstanceMagicMcpTokensListQuery
# mapDashboardInstanceMagicMcpTokensRemoveGroupsBody
# mapDashboardInstanceMagicMcpTokensRemoveGroupsOutput
# mapDashboardInstanceMagicMcpTokensUpdateBody
# mapDashboardInstanceMagicMcpTokensUpdateOutput
# mapDashboardInstancePortalsCreateBody
# mapDashboardInstancePortalsCreateOutput
# mapDashboardInstancePortalsDeleteOutput
# mapDashboardInstancePortalsGetOutput
# mapDashboardInstancePortalsListOutput
# mapDashboardInstancePortalsListQuery
# mapDashboardInstancePortalsUpdateBody
# mapDashboardInstancePortalsUpdateOutput
# mapDashboardInstanceProviderCategoriesGetOutput
# mapDashboardInstanceProviderCategoriesListOutput
# mapDashboardInstanceProviderCategoriesListQuery
# mapDashboardInstanceProviderCollectionsGetOutput
# mapDashboardInstanceProviderCollectionsListOutput
# mapDashboardInstanceProviderCollectionsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsDeleteOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsListOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsListOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsListOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsUpdateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsUpdateOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthCredentialsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsDeleteOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsListOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsListQuery
# mapDashboardInstanceProviderDeploymentsAuthCredentialsUpdateBody
# mapDashboardInstanceProviderDeploymentsAuthCredentialsUpdateOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsCreateBody
# mapDashboardInstanceProviderDeploymentsConfigVaultsCreateOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsDeleteOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsGetOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsListOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsListQuery
# mapDashboardInstanceProviderDeploymentsConfigVaultsUpdateBody
# mapDashboardInstanceProviderDeploymentsConfigVaultsUpdateOutput
# mapDashboardInstanceProviderDeploymentsConfigsCreateBody
# mapDashboardInstanceProviderDeploymentsConfigsCreateOutput
# mapDashboardInstanceProviderDeploymentsConfigsDeleteOutput
# mapDashboardInstanceProviderDeploymentsConfigsGetConfigSchemaOutput
# mapDashboardInstanceProviderDeploymentsConfigsGetConfigSchemaQuery
# mapDashboardInstanceProviderDeploymentsConfigsGetOutput
# mapDashboardInstanceProviderDeploymentsConfigsListOutput
# mapDashboardInstanceProviderDeploymentsConfigsListQuery
# mapDashboardInstanceProviderDeploymentsConfigsUpdateBody
# mapDashboardInstanceProviderDeploymentsConfigsUpdateOutput
# mapDashboardInstanceProviderDeploymentsCreateBody
# mapDashboardInstanceProviderDeploymentsCreateOutput
# mapDashboardInstanceProviderDeploymentsDeleteOutput
# mapDashboardInstanceProviderDeploymentsGetOutput
# mapDashboardInstanceProviderDeploymentsListOutput
# mapDashboardInstanceProviderDeploymentsListQuery
# mapDashboardInstanceProviderDeploymentsSetupSessionsCreateBody
# mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsDeleteOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsGetOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsListOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsListQuery
# mapDashboardInstanceProviderDeploymentsSetupSessionsUpdateBody
# mapDashboardInstanceProviderDeploymentsSetupSessionsUpdateOutput
# mapDashboardInstanceProviderDeploymentsUpdateBody
# mapDashboardInstanceProviderDeploymentsUpdateOutput
# mapDashboardInstanceProviderGroupsAddListingBody
# mapDashboardInstanceProviderGroupsAddListingOutput
# mapDashboardInstanceProviderGroupsCreateBody
# mapDashboardInstanceProviderGroupsCreateOutput
# mapDashboardInstanceProviderGroupsGetOutput
# mapDashboardInstanceProviderGroupsListOutput
# mapDashboardInstanceProviderGroupsListQuery
# mapDashboardInstanceProviderGroupsRemoveListingOutput
# mapDashboardInstanceProviderGroupsUpdateBody
# mapDashboardInstanceProviderGroupsUpdateOutput
# mapDashboardInstanceProviderListingsGetOutput
# mapDashboardInstanceProviderListingsListOutput
# mapDashboardInstanceProviderListingsListQuery
# mapDashboardInstanceProviderRunsGetLogsOutput
# mapDashboardInstanceProviderRunsGetOutput
# mapDashboardInstanceProviderRunsListOutput
# mapDashboardInstanceProviderRunsListQuery
# mapDashboardInstanceProviderTemplatesCreateBody
# mapDashboardInstanceProviderTemplatesCreateOutput
# mapDashboardInstanceProviderTemplatesDeleteOutput
# mapDashboardInstanceProviderTemplatesGetOutput
# mapDashboardInstanceProviderTemplatesListOutput
# mapDashboardInstanceProviderTemplatesListQuery
# mapDashboardInstanceProviderTemplatesUpdateBody
# mapDashboardInstanceProviderTemplatesUpdateOutput
# mapDashboardInstanceProvidersAuthMethodsGetOutput
# mapDashboardInstanceProvidersAuthMethodsListOutput
# mapDashboardInstanceProvidersAuthMethodsListQuery
# mapDashboardInstanceProvidersGetOutput
# mapDashboardInstanceProvidersListOutput
# mapDashboardInstanceProvidersListQuery
# mapDashboardInstanceProvidersSpecificationsGetOutput
# mapDashboardInstanceProvidersSpecificationsListOutput
# mapDashboardInstanceProvidersSpecificationsListQuery
# mapDashboardInstanceProvidersToolsGetOutput
# mapDashboardInstanceProvidersToolsListOutput
# mapDashboardInstanceProvidersToolsListQuery
# mapDashboardInstanceProvidersTriggersGetOutput
# mapDashboardInstanceProvidersTriggersListOutput
# mapDashboardInstanceProvidersTriggersListQuery
# mapDashboardInstanceProvidersVersionsGetOutput
# mapDashboardInstanceProvidersVersionsListOutput
# mapDashboardInstanceProvidersVersionsListQuery
# mapDashboardInstancePublishersGetOutput
# mapDashboardInstancePublishersListOutput
# mapDashboardInstancePublishersListQuery
# mapDashboardInstanceSessionTemplatesCreateBody
# mapDashboardInstanceSessionTemplatesCreateOutput
# mapDashboardInstanceSessionTemplatesGetOutput
# mapDashboardInstanceSessionTemplatesListOutput
# mapDashboardInstanceSessionTemplatesListQuery
# mapDashboardInstanceSessionTemplatesProvidersCreateBody
# mapDashboardInstanceSessionTemplatesProvidersCreateOutput
# mapDashboardInstanceSessionTemplatesProvidersDeleteOutput
# mapDashboardInstanceSessionTemplatesProvidersGetOutput
# mapDashboardInstanceSessionTemplatesProvidersListOutput
# mapDashboardInstanceSessionTemplatesProvidersListQuery
# mapDashboardInstanceSessionTemplatesProvidersUpdateBody
# mapDashboardInstanceSessionTemplatesProvidersUpdateOutput
# mapDashboardInstanceSessionTemplatesUpdateBody
# mapDashboardInstanceSessionTemplatesUpdateOutput
# mapDashboardInstanceSessionsConnectionsGetOutput
# mapDashboardInstanceSessionsConnectionsListOutput
# mapDashboardInstanceSessionsConnectionsListQuery
# mapDashboardInstanceSessionsCreateBody
# mapDashboardInstanceSessionsCreateOutput
# mapDashboardInstanceSessionsErrorGroupsGetOutput
# mapDashboardInstanceSessionsErrorGroupsListOutput
# mapDashboardInstanceSessionsErrorGroupsListQuery
# mapDashboardInstanceSessionsErrorsGetOutput
# mapDashboardInstanceSessionsErrorsListOutput
# mapDashboardInstanceSessionsErrorsListQuery
# mapDashboardInstanceSessionsEventsGetOutput
# mapDashboardInstanceSessionsEventsListOutput
# mapDashboardInstanceSessionsEventsListQuery
# mapDashboardInstanceSessionsGetOutput
# mapDashboardInstanceSessionsListOutput
# mapDashboardInstanceSessionsListQuery
# mapDashboardInstanceSessionsMessagesGetOutput
# mapDashboardInstanceSessionsMessagesListOutput
# mapDashboardInstanceSessionsMessagesListQuery
# mapDashboardInstanceSessionsParticipantsGetOutput
# mapDashboardInstanceSessionsParticipantsListOutput
# mapDashboardInstanceSessionsParticipantsListQuery
# mapDashboardInstanceSessionsProvidersCreateBody
# mapDashboardInstanceSessionsProvidersCreateOutput
# mapDashboardInstanceSessionsProvidersDeleteOutput
# mapDashboardInstanceSessionsProvidersGetOutput
# mapDashboardInstanceSessionsProvidersListOutput
# mapDashboardInstanceSessionsProvidersListQuery
# mapDashboardInstanceSessionsProvidersUpdateBody
# mapDashboardInstanceSessionsProvidersUpdateOutput
# mapDashboardInstanceSessionsUpdateBody
# mapDashboardInstanceSessionsUpdateOutput
# mapDashboardInstanceToolCallsCreateBody
# mapDashboardInstanceToolCallsCreateOutput
# mapDashboardInstanceToolCallsGetOutput
# mapDashboardInstanceToolCallsListOutput
# mapDashboardInstanceToolCallsListQuery
# mapInstancesGetOutput
# mapInstancesListOutput
# mapTokenGetOutput

# All types and mappers are available via:
# from .resources import *
# from .endpoints import *
