from .resources import *
from .endpoints import *

# Type exports for better discoverability
# Generated type exports
# These types are automatically exported for better IDE support

# Type classes
# ApiKeysCreateBody
# ApiKeysCreateOutput
# ApiKeysGetOutput
# ApiKeysListOutput
# ApiKeysListQuery
# ApiKeysRevealOutput
# ApiKeysRevokeOutput
# ApiKeysRotateBody
# ApiKeysRotateOutput
# ApiKeysUpdateBody
# ApiKeysUpdateOutput
# DashboardBootBody
# DashboardBootOutput
# DashboardInstanceCallbacksCreateBody
# DashboardInstanceCallbacksCreateOutput
# DashboardInstanceCallbacksDeleteOutput
# DashboardInstanceCallbacksDestinationsCreateBody
# DashboardInstanceCallbacksDestinationsCreateOutput
# DashboardInstanceCallbacksDestinationsDeleteOutput
# DashboardInstanceCallbacksDestinationsGetOutput
# DashboardInstanceCallbacksDestinationsListOutput
# DashboardInstanceCallbacksDestinationsListQuery
# DashboardInstanceCallbacksDestinationsUpdateBody
# DashboardInstanceCallbacksDestinationsUpdateOutput
# DashboardInstanceCallbacksEventsGetOutput
# DashboardInstanceCallbacksEventsListOutput
# DashboardInstanceCallbacksEventsListQuery
# DashboardInstanceCallbacksGetOutput
# DashboardInstanceCallbacksInstancesCreateBody
# DashboardInstanceCallbacksInstancesCreateOutput
# DashboardInstanceCallbacksInstancesDeleteOutput
# DashboardInstanceCallbacksInstancesListOutput
# DashboardInstanceCallbacksInstancesListQuery
# DashboardInstanceCallbacksListOutput
# DashboardInstanceCallbacksListQuery
# DashboardInstanceCallbacksNotificationsGetOutput
# DashboardInstanceCallbacksNotificationsListOutput
# DashboardInstanceCallbacksNotificationsListQuery
# DashboardInstanceCallbacksUpdateBody
# DashboardInstanceCallbacksUpdateOutput
# DashboardInstanceCustomProvidersCodeGetCodeEditorTokenOutput
# DashboardInstanceCustomProvidersCommitsCreateBody
# DashboardInstanceCustomProvidersCommitsCreateOutput
# DashboardInstanceCustomProvidersCommitsGetOutput
# DashboardInstanceCustomProvidersCommitsListOutput
# DashboardInstanceCustomProvidersCommitsListQuery
# DashboardInstanceCustomProvidersCreateBody
# DashboardInstanceCustomProvidersCreateOutput
# DashboardInstanceCustomProvidersDeploymentsGetLogsOutput
# DashboardInstanceCustomProvidersDeploymentsGetOutput
# DashboardInstanceCustomProvidersDeploymentsListOutput
# DashboardInstanceCustomProvidersDeploymentsListQuery
# DashboardInstanceCustomProvidersEnvironmentsGetOutput
# DashboardInstanceCustomProvidersEnvironmentsListOutput
# DashboardInstanceCustomProvidersEnvironmentsListQuery
# DashboardInstanceCustomProvidersGetOutput
# DashboardInstanceCustomProvidersListOutput
# DashboardInstanceCustomProvidersListQuery
# DashboardInstanceCustomProvidersUpdateBody
# DashboardInstanceCustomProvidersUpdateOutput
# DashboardInstanceCustomProvidersVersionsCreateBody
# DashboardInstanceCustomProvidersVersionsCreateOutput
# DashboardInstanceCustomProvidersVersionsGetOutput
# DashboardInstanceCustomProvidersVersionsListOutput
# DashboardInstanceCustomProvidersVersionsListQuery
# DashboardInstanceFileLinksCreateBody
# DashboardInstanceFileLinksCreateOutput
# DashboardInstanceFileLinksDeleteOutput
# DashboardInstanceFileLinksGetOutput
# DashboardInstanceFileLinksListOutput
# DashboardInstanceFileLinksListQuery
# DashboardInstanceFilesDeleteOutput
# DashboardInstanceFilesGetOutput
# DashboardInstanceFilesListOutput
# DashboardInstanceFilesListQuery
# DashboardInstanceIdentitiesCreateBody
# DashboardInstanceIdentitiesCreateOutput
# DashboardInstanceIdentitiesCredentialsCreateBody
# DashboardInstanceIdentitiesCredentialsCreateOutput
# DashboardInstanceIdentitiesCredentialsDeleteOutput
# DashboardInstanceIdentitiesCredentialsGetOutput
# DashboardInstanceIdentitiesCredentialsListOutput
# DashboardInstanceIdentitiesCredentialsListQuery
# DashboardInstanceIdentitiesCredentialsUpdateBody
# DashboardInstanceIdentitiesCredentialsUpdateOutput
# DashboardInstanceIdentitiesDelegationConfigsCreateBody
# DashboardInstanceIdentitiesDelegationConfigsCreateOutput
# DashboardInstanceIdentitiesDelegationConfigsDeleteOutput
# DashboardInstanceIdentitiesDelegationConfigsGetOutput
# DashboardInstanceIdentitiesDelegationConfigsListOutput
# DashboardInstanceIdentitiesDelegationConfigsListQuery
# DashboardInstanceIdentitiesDelegationConfigsUpdateBody
# DashboardInstanceIdentitiesDelegationConfigsUpdateOutput
# DashboardInstanceIdentitiesDelegationRequestsApproveOutput
# DashboardInstanceIdentitiesDelegationRequestsApproveQuery
# DashboardInstanceIdentitiesDelegationRequestsCreateBody
# DashboardInstanceIdentitiesDelegationRequestsCreateOutput
# DashboardInstanceIdentitiesDelegationRequestsDenyOutput
# DashboardInstanceIdentitiesDelegationRequestsDenyQuery
# DashboardInstanceIdentitiesDelegationRequestsGetOutput
# DashboardInstanceIdentitiesDelegationRequestsGetQuery
# DashboardInstanceIdentitiesDelegationRequestsListOutput
# DashboardInstanceIdentitiesDelegationRequestsListQuery
# DashboardInstanceIdentitiesDelegationsCreateBody
# DashboardInstanceIdentitiesDelegationsCreateOutput
# DashboardInstanceIdentitiesDelegationsGetOutput
# DashboardInstanceIdentitiesDelegationsListOutput
# DashboardInstanceIdentitiesDelegationsListQuery
# DashboardInstanceIdentitiesDelegationsRevokeOutput
# DashboardInstanceIdentitiesDeleteOutput
# DashboardInstanceIdentitiesGetOutput
# DashboardInstanceIdentitiesListOutput
# DashboardInstanceIdentitiesListQuery
# DashboardInstanceIdentitiesUpdateBody
# DashboardInstanceIdentitiesUpdateOutput
# DashboardInstanceIdentityActorsCreateBody
# DashboardInstanceIdentityActorsCreateOutput
# DashboardInstanceIdentityActorsDeleteOutput
# DashboardInstanceIdentityActorsGetOutput
# DashboardInstanceIdentityActorsListOutput
# DashboardInstanceIdentityActorsListQuery
# DashboardInstanceIdentityActorsUpdateBody
# DashboardInstanceIdentityActorsUpdateOutput
# DashboardInstanceMagicMcpGroupsAddServersBody
# DashboardInstanceMagicMcpGroupsAddServersOutput
# DashboardInstanceMagicMcpGroupsCreateBody
# DashboardInstanceMagicMcpGroupsCreateOutput
# DashboardInstanceMagicMcpGroupsDeleteOutput
# DashboardInstanceMagicMcpGroupsGetOutput
# DashboardInstanceMagicMcpGroupsListOutput
# DashboardInstanceMagicMcpGroupsListQuery
# DashboardInstanceMagicMcpGroupsRemoveServersBody
# DashboardInstanceMagicMcpGroupsRemoveServersOutput
# DashboardInstanceMagicMcpGroupsUpdateBody
# DashboardInstanceMagicMcpGroupsUpdateOutput
# DashboardInstanceMagicMcpServersCreateBody
# DashboardInstanceMagicMcpServersCreateOutput
# DashboardInstanceMagicMcpServersDeleteOutput
# DashboardInstanceMagicMcpServersGetOutput
# DashboardInstanceMagicMcpServersListOutput
# DashboardInstanceMagicMcpServersListQuery
# DashboardInstanceMagicMcpServersUpdateBody
# DashboardInstanceMagicMcpServersUpdateOutput
# DashboardInstanceMagicMcpSessionsGetOutput
# DashboardInstanceMagicMcpSessionsListOutput
# DashboardInstanceMagicMcpSessionsListQuery
# DashboardInstanceMagicMcpTokensAddGroupsBody
# DashboardInstanceMagicMcpTokensAddGroupsOutput
# DashboardInstanceMagicMcpTokensCreateBody
# DashboardInstanceMagicMcpTokensCreateOutput
# DashboardInstanceMagicMcpTokensDeleteOutput
# DashboardInstanceMagicMcpTokensGetOutput
# DashboardInstanceMagicMcpTokensListOutput
# DashboardInstanceMagicMcpTokensListQuery
# DashboardInstanceMagicMcpTokensRemoveGroupsBody
# DashboardInstanceMagicMcpTokensRemoveGroupsOutput
# DashboardInstanceMagicMcpTokensUpdateBody
# DashboardInstanceMagicMcpTokensUpdateOutput
# DashboardInstancePortalsAccessRequestsGetOutput
# DashboardInstancePortalsAccessRequestsListOutput
# DashboardInstancePortalsAccessRequestsListQuery
# DashboardInstancePortalsAccessRequestsUpdateBody
# DashboardInstancePortalsAccessRequestsUpdateOutput
# DashboardInstancePortalsAuthAppGetOutput
# DashboardInstancePortalsAuthSsoTenantsConnectionsListOutput
# DashboardInstancePortalsAuthSsoTenantsConnectionsListQuery
# DashboardInstancePortalsAuthSsoTenantsCreateBody
# DashboardInstancePortalsAuthSsoTenantsCreateOutput
# DashboardInstancePortalsAuthSsoTenantsListOutput
# DashboardInstancePortalsAuthSsoTenantsListQuery
# DashboardInstancePortalsAuthSsoTenantsSetupOutput
# DashboardInstancePortalsConsumerAccessCreateBody
# DashboardInstancePortalsConsumerAccessCreateOutput
# DashboardInstancePortalsConsumerAccessDeleteOutput
# DashboardInstancePortalsConsumerAccessGetOutput
# DashboardInstancePortalsConsumerAccessListOutput
# DashboardInstancePortalsConsumerAccessListQuery
# DashboardInstancePortalsConsumerGroupsCreateBody
# DashboardInstancePortalsConsumerGroupsCreateOutput
# DashboardInstancePortalsConsumerGroupsDeleteOutput
# DashboardInstancePortalsConsumerGroupsGetOutput
# DashboardInstancePortalsConsumerGroupsListOutput
# DashboardInstancePortalsConsumerGroupsListQuery
# DashboardInstancePortalsConsumerGroupsUpdateBody
# DashboardInstancePortalsConsumerGroupsUpdateOutput
# DashboardInstancePortalsConsumerProfilesAssignGroupsBody
# DashboardInstancePortalsConsumerProfilesAssignGroupsOutput
# DashboardInstancePortalsConsumerProfilesGetOutput
# DashboardInstancePortalsConsumerProfilesListOutput
# DashboardInstancePortalsConsumerProfilesListQuery
# DashboardInstancePortalsConsumerProfilesUnassignGroupsBody
# DashboardInstancePortalsConsumerProfilesUnassignGroupsOutput
# DashboardInstancePortalsCreateBody
# DashboardInstancePortalsCreateOutput
# DashboardInstancePortalsDeleteOutput
# DashboardInstancePortalsGetOutput
# DashboardInstancePortalsListOutput
# DashboardInstancePortalsListQuery
# DashboardInstancePortalsUpdateBody
# DashboardInstancePortalsUpdateOutput
# DashboardInstanceProviderCategoriesGetOutput
# DashboardInstanceProviderCategoriesListOutput
# DashboardInstanceProviderCategoriesListQuery
# DashboardInstanceProviderCollectionsGetOutput
# DashboardInstanceProviderCollectionsListOutput
# DashboardInstanceProviderCollectionsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsCreateBody
# DashboardInstanceProviderDeploymentsAuthConfigsCreateOutput
# DashboardInstanceProviderDeploymentsAuthConfigsDeleteOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsCreateBody
# DashboardInstanceProviderDeploymentsAuthConfigsExportsCreateOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsGetOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsListOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsGetOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsCreateBody
# DashboardInstanceProviderDeploymentsAuthConfigsImportsCreateOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsGetOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaQuery
# DashboardInstanceProviderDeploymentsAuthConfigsImportsListOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsListOutput
# DashboardInstanceProviderDeploymentsAuthConfigsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsUpdateBody
# DashboardInstanceProviderDeploymentsAuthConfigsUpdateOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsCreateBody
# DashboardInstanceProviderDeploymentsAuthCredentialsCreateOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsDeleteOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsGetOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsListOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsListQuery
# DashboardInstanceProviderDeploymentsAuthCredentialsUpdateBody
# DashboardInstanceProviderDeploymentsAuthCredentialsUpdateOutput
# DashboardInstanceProviderDeploymentsConfigVaultsCreateBody
# DashboardInstanceProviderDeploymentsConfigVaultsCreateOutput
# DashboardInstanceProviderDeploymentsConfigVaultsDeleteOutput
# DashboardInstanceProviderDeploymentsConfigVaultsGetOutput
# DashboardInstanceProviderDeploymentsConfigVaultsListOutput
# DashboardInstanceProviderDeploymentsConfigVaultsListQuery
# DashboardInstanceProviderDeploymentsConfigVaultsUpdateBody
# DashboardInstanceProviderDeploymentsConfigVaultsUpdateOutput
# DashboardInstanceProviderDeploymentsConfigsCreateBody
# DashboardInstanceProviderDeploymentsConfigsCreateOutput
# DashboardInstanceProviderDeploymentsConfigsDeleteOutput
# DashboardInstanceProviderDeploymentsConfigsGetConfigSchemaOutput
# DashboardInstanceProviderDeploymentsConfigsGetConfigSchemaQuery
# DashboardInstanceProviderDeploymentsConfigsGetOutput
# DashboardInstanceProviderDeploymentsConfigsListOutput
# DashboardInstanceProviderDeploymentsConfigsListQuery
# DashboardInstanceProviderDeploymentsConfigsUpdateBody
# DashboardInstanceProviderDeploymentsConfigsUpdateOutput
# DashboardInstanceProviderDeploymentsCreateBody
# DashboardInstanceProviderDeploymentsCreateOutput
# DashboardInstanceProviderDeploymentsDeleteOutput
# DashboardInstanceProviderDeploymentsGetOutput
# DashboardInstanceProviderDeploymentsListOutput
# DashboardInstanceProviderDeploymentsListQuery
# DashboardInstanceProviderDeploymentsSetupSessionsCreateBody
# DashboardInstanceProviderDeploymentsSetupSessionsCreateOutput
# DashboardInstanceProviderDeploymentsSetupSessionsDeleteOutput
# DashboardInstanceProviderDeploymentsSetupSessionsGetOutput
# DashboardInstanceProviderDeploymentsSetupSessionsListOutput
# DashboardInstanceProviderDeploymentsSetupSessionsListQuery
# DashboardInstanceProviderDeploymentsSetupSessionsUpdateBody
# DashboardInstanceProviderDeploymentsSetupSessionsUpdateOutput
# DashboardInstanceProviderDeploymentsUpdateBody
# DashboardInstanceProviderDeploymentsUpdateOutput
# DashboardInstanceProviderGroupsAddListingBody
# DashboardInstanceProviderGroupsAddListingOutput
# DashboardInstanceProviderGroupsCreateBody
# DashboardInstanceProviderGroupsCreateOutput
# DashboardInstanceProviderGroupsGetOutput
# DashboardInstanceProviderGroupsListOutput
# DashboardInstanceProviderGroupsListQuery
# DashboardInstanceProviderGroupsRemoveListingOutput
# DashboardInstanceProviderGroupsUpdateBody
# DashboardInstanceProviderGroupsUpdateOutput
# DashboardInstanceProviderListingsGetOutput
# DashboardInstanceProviderListingsListOutput
# DashboardInstanceProviderListingsListQuery
# DashboardInstanceProviderRunsGetLogsOutput
# DashboardInstanceProviderRunsGetOutput
# DashboardInstanceProviderRunsListOutput
# DashboardInstanceProviderRunsListQuery
# DashboardInstanceProviderTemplatesCreateBody
# DashboardInstanceProviderTemplatesCreateOutput
# DashboardInstanceProviderTemplatesDeleteOutput
# DashboardInstanceProviderTemplatesGetOutput
# DashboardInstanceProviderTemplatesListOutput
# DashboardInstanceProviderTemplatesListQuery
# DashboardInstanceProviderTemplatesUpdateBody
# DashboardInstanceProviderTemplatesUpdateOutput
# DashboardInstanceProvidersAuthMethodsGetOutput
# DashboardInstanceProvidersAuthMethodsListOutput
# DashboardInstanceProvidersAuthMethodsListQuery
# DashboardInstanceProvidersGetOutput
# DashboardInstanceProvidersListOutput
# DashboardInstanceProvidersListQuery
# DashboardInstanceProvidersSpecificationsGetOutput
# DashboardInstanceProvidersSpecificationsListOutput
# DashboardInstanceProvidersSpecificationsListQuery
# DashboardInstanceProvidersToolsGetOutput
# DashboardInstanceProvidersToolsListOutput
# DashboardInstanceProvidersToolsListQuery
# DashboardInstanceProvidersTriggersGetOutput
# DashboardInstanceProvidersTriggersListOutput
# DashboardInstanceProvidersTriggersListQuery
# DashboardInstanceProvidersVersionsGetOutput
# DashboardInstanceProvidersVersionsListOutput
# DashboardInstanceProvidersVersionsListQuery
# DashboardInstancePublishersGetOutput
# DashboardInstancePublishersListOutput
# DashboardInstancePublishersListQuery
# DashboardInstanceScmAccountsPreviewBody
# DashboardInstanceScmAccountsPreviewOutput
# DashboardInstanceScmInstallationCreateBody
# DashboardInstanceScmInstallationCreateOutput
# DashboardInstanceScmInstallationListOutput
# DashboardInstanceScmInstallationListQuery
# DashboardInstanceScmReposCreateBody
# DashboardInstanceScmReposCreateOutput
# DashboardInstanceScmReposPreviewBody
# DashboardInstanceScmReposPreviewOutput
# DashboardInstanceSessionTemplatesCreateBody
# DashboardInstanceSessionTemplatesCreateOutput
# DashboardInstanceSessionTemplatesGetOutput
# DashboardInstanceSessionTemplatesListOutput
# DashboardInstanceSessionTemplatesListQuery
# DashboardInstanceSessionTemplatesProvidersCreateBody
# DashboardInstanceSessionTemplatesProvidersCreateOutput
# DashboardInstanceSessionTemplatesProvidersDeleteOutput
# DashboardInstanceSessionTemplatesProvidersGetOutput
# DashboardInstanceSessionTemplatesProvidersListOutput
# DashboardInstanceSessionTemplatesProvidersListQuery
# DashboardInstanceSessionTemplatesProvidersUpdateBody
# DashboardInstanceSessionTemplatesProvidersUpdateOutput
# DashboardInstanceSessionTemplatesUpdateBody
# DashboardInstanceSessionTemplatesUpdateOutput
# DashboardInstanceSessionsConnectionsGetOutput
# DashboardInstanceSessionsConnectionsListOutput
# DashboardInstanceSessionsConnectionsListQuery
# DashboardInstanceSessionsCreateBody
# DashboardInstanceSessionsCreateOutput
# DashboardInstanceSessionsErrorGroupsGetOutput
# DashboardInstanceSessionsErrorGroupsListOutput
# DashboardInstanceSessionsErrorGroupsListQuery
# DashboardInstanceSessionsErrorsGetOutput
# DashboardInstanceSessionsErrorsListOutput
# DashboardInstanceSessionsErrorsListQuery
# DashboardInstanceSessionsEventsGetOutput
# DashboardInstanceSessionsEventsListOutput
# DashboardInstanceSessionsEventsListQuery
# DashboardInstanceSessionsGetOutput
# DashboardInstanceSessionsListOutput
# DashboardInstanceSessionsListQuery
# DashboardInstanceSessionsMessagesGetOutput
# DashboardInstanceSessionsMessagesListOutput
# DashboardInstanceSessionsMessagesListQuery
# DashboardInstanceSessionsParticipantsGetOutput
# DashboardInstanceSessionsParticipantsListOutput
# DashboardInstanceSessionsParticipantsListQuery
# DashboardInstanceSessionsProvidersCreateBody
# DashboardInstanceSessionsProvidersCreateOutput
# DashboardInstanceSessionsProvidersDeleteOutput
# DashboardInstanceSessionsProvidersGetOutput
# DashboardInstanceSessionsProvidersListOutput
# DashboardInstanceSessionsProvidersListQuery
# DashboardInstanceSessionsProvidersUpdateBody
# DashboardInstanceSessionsProvidersUpdateOutput
# DashboardInstanceSessionsUpdateBody
# DashboardInstanceSessionsUpdateOutput
# DashboardInstanceToolCallsCreateBody
# DashboardInstanceToolCallsCreateOutput
# DashboardInstanceToolCallsGetOutput
# DashboardInstanceToolCallsListOutput
# DashboardInstanceToolCallsListQuery
# DashboardOauthAuthorizationRequestsApproveBody
# DashboardOauthAuthorizationRequestsApproveOutput
# DashboardOauthAuthorizationRequestsGetOutput
# DashboardOauthAuthorizationRequestsRejectBody
# DashboardOauthAuthorizationRequestsRejectOutput
# DashboardOrganizationsAccessPoliciesCreateBody
# DashboardOrganizationsAccessPoliciesCreateOutput
# DashboardOrganizationsAccessPoliciesDeleteOutput
# DashboardOrganizationsAccessPoliciesGetOutput
# DashboardOrganizationsAccessPoliciesListOutput
# DashboardOrganizationsAccessPoliciesListQuery
# DashboardOrganizationsAccessPoliciesUpdateBody
# DashboardOrganizationsAccessPoliciesUpdateOutput
# DashboardOrganizationsAccessPoliciesVersionsOutput
# DashboardOrganizationsAccessPoliciesVersionsQuery
# DashboardOrganizationsAccessRolesCreateBody
# DashboardOrganizationsAccessRolesCreateOutput
# DashboardOrganizationsAccessRolesDeleteOutput
# DashboardOrganizationsAccessRolesGetOutput
# DashboardOrganizationsAccessRolesListOutput
# DashboardOrganizationsAccessRolesListQuery
# DashboardOrganizationsAccessRolesUpdateBody
# DashboardOrganizationsAccessRolesUpdateOutput
# DashboardOrganizationsAccessRolesVersionsOutput
# DashboardOrganizationsAccessRolesVersionsQuery
# DashboardOrganizationsCreateBody
# DashboardOrganizationsCreateOutput
# DashboardOrganizationsDeleteOutput
# DashboardOrganizationsGetOutput
# DashboardOrganizationsInstancesCreateBody
# DashboardOrganizationsInstancesCreateOutput
# DashboardOrganizationsInstancesDeleteOutput
# DashboardOrganizationsInstancesGetOutput
# DashboardOrganizationsInstancesListOutput
# DashboardOrganizationsInstancesListQuery
# DashboardOrganizationsInstancesUpdateBody
# DashboardOrganizationsInstancesUpdateOutput
# DashboardOrganizationsInvitesCreateBody
# DashboardOrganizationsInvitesCreateOutput
# DashboardOrganizationsInvitesDeleteOutput
# DashboardOrganizationsInvitesEnsureLinkOutput
# DashboardOrganizationsInvitesGetOutput
# DashboardOrganizationsInvitesListOutput
# DashboardOrganizationsInvitesListQuery
# DashboardOrganizationsInvitesUpdateBody
# DashboardOrganizationsInvitesUpdateOutput
# DashboardOrganizationsJoinAcceptBody
# DashboardOrganizationsJoinAcceptOutput
# DashboardOrganizationsJoinGetOutput
# DashboardOrganizationsJoinGetQuery
# DashboardOrganizationsJoinRejectBody
# DashboardOrganizationsJoinRejectOutput
# DashboardOrganizationsListOutput
# DashboardOrganizationsListQuery
# DashboardOrganizationsMembersDeleteOutput
# DashboardOrganizationsMembersGetOutput
# DashboardOrganizationsMembersListOutput
# DashboardOrganizationsMembersListQuery
# DashboardOrganizationsMembersPoliciesCreateBody
# DashboardOrganizationsMembersPoliciesCreateOutput
# DashboardOrganizationsMembersPoliciesDeleteOutput
# DashboardOrganizationsMembersUpdateBody
# DashboardOrganizationsMembersUpdateOutput
# DashboardOrganizationsOauthAppsClientSecretsCreateOutput
# DashboardOrganizationsOauthAppsClientSecretsDeleteOutput
# DashboardOrganizationsOauthAppsCreateBody
# DashboardOrganizationsOauthAppsCreateOutput
# DashboardOrganizationsOauthAppsDeleteOutput
# DashboardOrganizationsOauthAppsGetOutput
# DashboardOrganizationsOauthAppsListOutput
# DashboardOrganizationsOauthAppsListQuery
# DashboardOrganizationsOauthAppsUpdateBody
# DashboardOrganizationsOauthAppsUpdateOutput
# DashboardOrganizationsOauthAuthorizationLogsListOutput
# DashboardOrganizationsOauthAuthorizationLogsListQuery
# DashboardOrganizationsOauthAuthorizationsGetOutput
# DashboardOrganizationsOauthAuthorizationsListOutput
# DashboardOrganizationsOauthAuthorizationsListQuery
# DashboardOrganizationsOauthAuthorizationsRevokeOutput
# DashboardOrganizationsOauthCliDevicesGetOutput
# DashboardOrganizationsOauthCliDevicesListOutput
# DashboardOrganizationsOauthCliDevicesListQuery
# DashboardOrganizationsOauthInstallationsGetOutput
# DashboardOrganizationsOauthInstallationsListOutput
# DashboardOrganizationsOauthInstallationsListQuery
# DashboardOrganizationsOauthInstallationsRevokeOutput
# DashboardOrganizationsOauthScopesListOutput
# DashboardOrganizationsProjectsBrandingGetOutput
# DashboardOrganizationsProjectsBrandingUpdateBody
# DashboardOrganizationsProjectsBrandingUpdateOutput
# DashboardOrganizationsProjectsCreateBody
# DashboardOrganizationsProjectsCreateOutput
# DashboardOrganizationsProjectsDeleteOutput
# DashboardOrganizationsProjectsGetOutput
# DashboardOrganizationsProjectsListOutput
# DashboardOrganizationsProjectsListQuery
# DashboardOrganizationsProjectsUpdateBody
# DashboardOrganizationsProjectsUpdateOutput
# DashboardOrganizationsServiceAccountsClientSecretsCreateOutput
# DashboardOrganizationsServiceAccountsClientSecretsDeleteOutput
# DashboardOrganizationsServiceAccountsCreateBody
# DashboardOrganizationsServiceAccountsCreateOutput
# DashboardOrganizationsServiceAccountsCredentialsGetOutput
# DashboardOrganizationsServiceAccountsCredentialsListOutput
# DashboardOrganizationsServiceAccountsCredentialsListQuery
# DashboardOrganizationsServiceAccountsDeleteOutput
# DashboardOrganizationsServiceAccountsGetOutput
# DashboardOrganizationsServiceAccountsListOutput
# DashboardOrganizationsServiceAccountsListQuery
# DashboardOrganizationsServiceAccountsPoliciesCreateBody
# DashboardOrganizationsServiceAccountsPoliciesCreateOutput
# DashboardOrganizationsServiceAccountsPoliciesDeleteOutput
# DashboardOrganizationsServiceAccountsUpdateBody
# DashboardOrganizationsServiceAccountsUpdateOutput
# DashboardOrganizationsTeamsCreateBody
# DashboardOrganizationsTeamsCreateOutput
# DashboardOrganizationsTeamsGetOutput
# DashboardOrganizationsTeamsListOutput
# DashboardOrganizationsTeamsListQuery
# DashboardOrganizationsTeamsMembersCreateBody
# DashboardOrganizationsTeamsMembersCreateOutput
# DashboardOrganizationsTeamsMembersDeleteOutput
# DashboardOrganizationsTeamsPoliciesCreateBody
# DashboardOrganizationsTeamsPoliciesCreateOutput
# DashboardOrganizationsTeamsPoliciesDeleteOutput
# DashboardOrganizationsTeamsUpdateBody
# DashboardOrganizationsTeamsUpdateOutput
# DashboardOrganizationsUpdateBody
# DashboardOrganizationsUpdateOutput
# DashboardUsageTimelineOutput
# DashboardUsageTimelineQuery
# ManagementOrganizationGetOutput
# ManagementOrganizationUpdateBody
# ManagementOrganizationUpdateOutput
# ManagementUserDeleteBody
# ManagementUserDeleteOutput
# ManagementUserGetOutput
# ManagementUserUpdateBody
# ManagementUserUpdateOutput
# OrganizationsFlagsGetOutput
# OrganizationsProfileGetOutput
# OrganizationsProfileUpdateBody
# OrganizationsProfileUpdateOutput

# Mapper classes
# mapApiKeysCreateBody
# mapApiKeysCreateOutput
# mapApiKeysGetOutput
# mapApiKeysListOutput
# mapApiKeysListQuery
# mapApiKeysRevealOutput
# mapApiKeysRevokeOutput
# mapApiKeysRotateBody
# mapApiKeysRotateOutput
# mapApiKeysUpdateBody
# mapApiKeysUpdateOutput
# mapDashboardBootBody
# mapDashboardBootOutput
# mapDashboardInstanceCallbacksCreateBody
# mapDashboardInstanceCallbacksCreateOutput
# mapDashboardInstanceCallbacksDeleteOutput
# mapDashboardInstanceCallbacksDestinationsCreateBody
# mapDashboardInstanceCallbacksDestinationsCreateOutput
# mapDashboardInstanceCallbacksDestinationsDeleteOutput
# mapDashboardInstanceCallbacksDestinationsGetOutput
# mapDashboardInstanceCallbacksDestinationsListOutput
# mapDashboardInstanceCallbacksDestinationsListQuery
# mapDashboardInstanceCallbacksDestinationsUpdateBody
# mapDashboardInstanceCallbacksDestinationsUpdateOutput
# mapDashboardInstanceCallbacksEventsGetOutput
# mapDashboardInstanceCallbacksEventsListOutput
# mapDashboardInstanceCallbacksEventsListQuery
# mapDashboardInstanceCallbacksGetOutput
# mapDashboardInstanceCallbacksInstancesCreateBody
# mapDashboardInstanceCallbacksInstancesCreateOutput
# mapDashboardInstanceCallbacksInstancesDeleteOutput
# mapDashboardInstanceCallbacksInstancesListOutput
# mapDashboardInstanceCallbacksInstancesListQuery
# mapDashboardInstanceCallbacksListOutput
# mapDashboardInstanceCallbacksListQuery
# mapDashboardInstanceCallbacksNotificationsGetOutput
# mapDashboardInstanceCallbacksNotificationsListOutput
# mapDashboardInstanceCallbacksNotificationsListQuery
# mapDashboardInstanceCallbacksUpdateBody
# mapDashboardInstanceCallbacksUpdateOutput
# mapDashboardInstanceCustomProvidersCodeGetCodeEditorTokenOutput
# mapDashboardInstanceCustomProvidersCommitsCreateBody
# mapDashboardInstanceCustomProvidersCommitsCreateOutput
# mapDashboardInstanceCustomProvidersCommitsGetOutput
# mapDashboardInstanceCustomProvidersCommitsListOutput
# mapDashboardInstanceCustomProvidersCommitsListQuery
# mapDashboardInstanceCustomProvidersCreateBody
# mapDashboardInstanceCustomProvidersCreateOutput
# mapDashboardInstanceCustomProvidersDeploymentsGetLogsOutput
# mapDashboardInstanceCustomProvidersDeploymentsGetOutput
# mapDashboardInstanceCustomProvidersDeploymentsListOutput
# mapDashboardInstanceCustomProvidersDeploymentsListQuery
# mapDashboardInstanceCustomProvidersEnvironmentsGetOutput
# mapDashboardInstanceCustomProvidersEnvironmentsListOutput
# mapDashboardInstanceCustomProvidersEnvironmentsListQuery
# mapDashboardInstanceCustomProvidersGetOutput
# mapDashboardInstanceCustomProvidersListOutput
# mapDashboardInstanceCustomProvidersListQuery
# mapDashboardInstanceCustomProvidersUpdateBody
# mapDashboardInstanceCustomProvidersUpdateOutput
# mapDashboardInstanceCustomProvidersVersionsCreateBody
# mapDashboardInstanceCustomProvidersVersionsCreateOutput
# mapDashboardInstanceCustomProvidersVersionsGetOutput
# mapDashboardInstanceCustomProvidersVersionsListOutput
# mapDashboardInstanceCustomProvidersVersionsListQuery
# mapDashboardInstanceFileLinksCreateBody
# mapDashboardInstanceFileLinksCreateOutput
# mapDashboardInstanceFileLinksDeleteOutput
# mapDashboardInstanceFileLinksGetOutput
# mapDashboardInstanceFileLinksListOutput
# mapDashboardInstanceFileLinksListQuery
# mapDashboardInstanceFilesDeleteOutput
# mapDashboardInstanceFilesGetOutput
# mapDashboardInstanceFilesListOutput
# mapDashboardInstanceFilesListQuery
# mapDashboardInstanceIdentitiesCreateBody
# mapDashboardInstanceIdentitiesCreateOutput
# mapDashboardInstanceIdentitiesCredentialsCreateBody
# mapDashboardInstanceIdentitiesCredentialsCreateOutput
# mapDashboardInstanceIdentitiesCredentialsDeleteOutput
# mapDashboardInstanceIdentitiesCredentialsGetOutput
# mapDashboardInstanceIdentitiesCredentialsListOutput
# mapDashboardInstanceIdentitiesCredentialsListQuery
# mapDashboardInstanceIdentitiesCredentialsUpdateBody
# mapDashboardInstanceIdentitiesCredentialsUpdateOutput
# mapDashboardInstanceIdentitiesDelegationConfigsCreateBody
# mapDashboardInstanceIdentitiesDelegationConfigsCreateOutput
# mapDashboardInstanceIdentitiesDelegationConfigsDeleteOutput
# mapDashboardInstanceIdentitiesDelegationConfigsGetOutput
# mapDashboardInstanceIdentitiesDelegationConfigsListOutput
# mapDashboardInstanceIdentitiesDelegationConfigsListQuery
# mapDashboardInstanceIdentitiesDelegationConfigsUpdateBody
# mapDashboardInstanceIdentitiesDelegationConfigsUpdateOutput
# mapDashboardInstanceIdentitiesDelegationRequestsApproveOutput
# mapDashboardInstanceIdentitiesDelegationRequestsApproveQuery
# mapDashboardInstanceIdentitiesDelegationRequestsCreateBody
# mapDashboardInstanceIdentitiesDelegationRequestsCreateOutput
# mapDashboardInstanceIdentitiesDelegationRequestsDenyOutput
# mapDashboardInstanceIdentitiesDelegationRequestsDenyQuery
# mapDashboardInstanceIdentitiesDelegationRequestsGetOutput
# mapDashboardInstanceIdentitiesDelegationRequestsGetQuery
# mapDashboardInstanceIdentitiesDelegationRequestsListOutput
# mapDashboardInstanceIdentitiesDelegationRequestsListQuery
# mapDashboardInstanceIdentitiesDelegationsCreateBody
# mapDashboardInstanceIdentitiesDelegationsCreateOutput
# mapDashboardInstanceIdentitiesDelegationsGetOutput
# mapDashboardInstanceIdentitiesDelegationsListOutput
# mapDashboardInstanceIdentitiesDelegationsListQuery
# mapDashboardInstanceIdentitiesDelegationsRevokeOutput
# mapDashboardInstanceIdentitiesDeleteOutput
# mapDashboardInstanceIdentitiesGetOutput
# mapDashboardInstanceIdentitiesListOutput
# mapDashboardInstanceIdentitiesListQuery
# mapDashboardInstanceIdentitiesUpdateBody
# mapDashboardInstanceIdentitiesUpdateOutput
# mapDashboardInstanceIdentityActorsCreateBody
# mapDashboardInstanceIdentityActorsCreateOutput
# mapDashboardInstanceIdentityActorsDeleteOutput
# mapDashboardInstanceIdentityActorsGetOutput
# mapDashboardInstanceIdentityActorsListOutput
# mapDashboardInstanceIdentityActorsListQuery
# mapDashboardInstanceIdentityActorsUpdateBody
# mapDashboardInstanceIdentityActorsUpdateOutput
# mapDashboardInstanceMagicMcpGroupsAddServersBody
# mapDashboardInstanceMagicMcpGroupsAddServersOutput
# mapDashboardInstanceMagicMcpGroupsCreateBody
# mapDashboardInstanceMagicMcpGroupsCreateOutput
# mapDashboardInstanceMagicMcpGroupsDeleteOutput
# mapDashboardInstanceMagicMcpGroupsGetOutput
# mapDashboardInstanceMagicMcpGroupsListOutput
# mapDashboardInstanceMagicMcpGroupsListQuery
# mapDashboardInstanceMagicMcpGroupsRemoveServersBody
# mapDashboardInstanceMagicMcpGroupsRemoveServersOutput
# mapDashboardInstanceMagicMcpGroupsUpdateBody
# mapDashboardInstanceMagicMcpGroupsUpdateOutput
# mapDashboardInstanceMagicMcpServersCreateBody
# mapDashboardInstanceMagicMcpServersCreateOutput
# mapDashboardInstanceMagicMcpServersDeleteOutput
# mapDashboardInstanceMagicMcpServersGetOutput
# mapDashboardInstanceMagicMcpServersListOutput
# mapDashboardInstanceMagicMcpServersListQuery
# mapDashboardInstanceMagicMcpServersUpdateBody
# mapDashboardInstanceMagicMcpServersUpdateOutput
# mapDashboardInstanceMagicMcpSessionsGetOutput
# mapDashboardInstanceMagicMcpSessionsListOutput
# mapDashboardInstanceMagicMcpSessionsListQuery
# mapDashboardInstanceMagicMcpTokensAddGroupsBody
# mapDashboardInstanceMagicMcpTokensAddGroupsOutput
# mapDashboardInstanceMagicMcpTokensCreateBody
# mapDashboardInstanceMagicMcpTokensCreateOutput
# mapDashboardInstanceMagicMcpTokensDeleteOutput
# mapDashboardInstanceMagicMcpTokensGetOutput
# mapDashboardInstanceMagicMcpTokensListOutput
# mapDashboardInstanceMagicMcpTokensListQuery
# mapDashboardInstanceMagicMcpTokensRemoveGroupsBody
# mapDashboardInstanceMagicMcpTokensRemoveGroupsOutput
# mapDashboardInstanceMagicMcpTokensUpdateBody
# mapDashboardInstanceMagicMcpTokensUpdateOutput
# mapDashboardInstancePortalsAccessRequestsGetOutput
# mapDashboardInstancePortalsAccessRequestsListOutput
# mapDashboardInstancePortalsAccessRequestsListQuery
# mapDashboardInstancePortalsAccessRequestsUpdateBody
# mapDashboardInstancePortalsAccessRequestsUpdateOutput
# mapDashboardInstancePortalsAuthAppGetOutput
# mapDashboardInstancePortalsAuthSsoTenantsConnectionsListOutput
# mapDashboardInstancePortalsAuthSsoTenantsConnectionsListQuery
# mapDashboardInstancePortalsAuthSsoTenantsCreateBody
# mapDashboardInstancePortalsAuthSsoTenantsCreateOutput
# mapDashboardInstancePortalsAuthSsoTenantsListOutput
# mapDashboardInstancePortalsAuthSsoTenantsListQuery
# mapDashboardInstancePortalsAuthSsoTenantsSetupOutput
# mapDashboardInstancePortalsConsumerAccessCreateBody
# mapDashboardInstancePortalsConsumerAccessCreateOutput
# mapDashboardInstancePortalsConsumerAccessDeleteOutput
# mapDashboardInstancePortalsConsumerAccessGetOutput
# mapDashboardInstancePortalsConsumerAccessListOutput
# mapDashboardInstancePortalsConsumerAccessListQuery
# mapDashboardInstancePortalsConsumerGroupsCreateBody
# mapDashboardInstancePortalsConsumerGroupsCreateOutput
# mapDashboardInstancePortalsConsumerGroupsDeleteOutput
# mapDashboardInstancePortalsConsumerGroupsGetOutput
# mapDashboardInstancePortalsConsumerGroupsListOutput
# mapDashboardInstancePortalsConsumerGroupsListQuery
# mapDashboardInstancePortalsConsumerGroupsUpdateBody
# mapDashboardInstancePortalsConsumerGroupsUpdateOutput
# mapDashboardInstancePortalsConsumerProfilesAssignGroupsBody
# mapDashboardInstancePortalsConsumerProfilesAssignGroupsOutput
# mapDashboardInstancePortalsConsumerProfilesGetOutput
# mapDashboardInstancePortalsConsumerProfilesListOutput
# mapDashboardInstancePortalsConsumerProfilesListQuery
# mapDashboardInstancePortalsConsumerProfilesUnassignGroupsBody
# mapDashboardInstancePortalsConsumerProfilesUnassignGroupsOutput
# mapDashboardInstancePortalsCreateBody
# mapDashboardInstancePortalsCreateOutput
# mapDashboardInstancePortalsDeleteOutput
# mapDashboardInstancePortalsGetOutput
# mapDashboardInstancePortalsListOutput
# mapDashboardInstancePortalsListQuery
# mapDashboardInstancePortalsUpdateBody
# mapDashboardInstancePortalsUpdateOutput
# mapDashboardInstanceProviderCategoriesGetOutput
# mapDashboardInstanceProviderCategoriesListOutput
# mapDashboardInstanceProviderCategoriesListQuery
# mapDashboardInstanceProviderCollectionsGetOutput
# mapDashboardInstanceProviderCollectionsListOutput
# mapDashboardInstanceProviderCollectionsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsDeleteOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsListOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsListOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsListOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsUpdateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsUpdateOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthCredentialsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsDeleteOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsListOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsListQuery
# mapDashboardInstanceProviderDeploymentsAuthCredentialsUpdateBody
# mapDashboardInstanceProviderDeploymentsAuthCredentialsUpdateOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsCreateBody
# mapDashboardInstanceProviderDeploymentsConfigVaultsCreateOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsDeleteOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsGetOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsListOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsListQuery
# mapDashboardInstanceProviderDeploymentsConfigVaultsUpdateBody
# mapDashboardInstanceProviderDeploymentsConfigVaultsUpdateOutput
# mapDashboardInstanceProviderDeploymentsConfigsCreateBody
# mapDashboardInstanceProviderDeploymentsConfigsCreateOutput
# mapDashboardInstanceProviderDeploymentsConfigsDeleteOutput
# mapDashboardInstanceProviderDeploymentsConfigsGetConfigSchemaOutput
# mapDashboardInstanceProviderDeploymentsConfigsGetConfigSchemaQuery
# mapDashboardInstanceProviderDeploymentsConfigsGetOutput
# mapDashboardInstanceProviderDeploymentsConfigsListOutput
# mapDashboardInstanceProviderDeploymentsConfigsListQuery
# mapDashboardInstanceProviderDeploymentsConfigsUpdateBody
# mapDashboardInstanceProviderDeploymentsConfigsUpdateOutput
# mapDashboardInstanceProviderDeploymentsCreateBody
# mapDashboardInstanceProviderDeploymentsCreateOutput
# mapDashboardInstanceProviderDeploymentsDeleteOutput
# mapDashboardInstanceProviderDeploymentsGetOutput
# mapDashboardInstanceProviderDeploymentsListOutput
# mapDashboardInstanceProviderDeploymentsListQuery
# mapDashboardInstanceProviderDeploymentsSetupSessionsCreateBody
# mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsDeleteOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsGetOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsListOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsListQuery
# mapDashboardInstanceProviderDeploymentsSetupSessionsUpdateBody
# mapDashboardInstanceProviderDeploymentsSetupSessionsUpdateOutput
# mapDashboardInstanceProviderDeploymentsUpdateBody
# mapDashboardInstanceProviderDeploymentsUpdateOutput
# mapDashboardInstanceProviderGroupsAddListingBody
# mapDashboardInstanceProviderGroupsAddListingOutput
# mapDashboardInstanceProviderGroupsCreateBody
# mapDashboardInstanceProviderGroupsCreateOutput
# mapDashboardInstanceProviderGroupsGetOutput
# mapDashboardInstanceProviderGroupsListOutput
# mapDashboardInstanceProviderGroupsListQuery
# mapDashboardInstanceProviderGroupsRemoveListingOutput
# mapDashboardInstanceProviderGroupsUpdateBody
# mapDashboardInstanceProviderGroupsUpdateOutput
# mapDashboardInstanceProviderListingsGetOutput
# mapDashboardInstanceProviderListingsListOutput
# mapDashboardInstanceProviderListingsListQuery
# mapDashboardInstanceProviderRunsGetLogsOutput
# mapDashboardInstanceProviderRunsGetOutput
# mapDashboardInstanceProviderRunsListOutput
# mapDashboardInstanceProviderRunsListQuery
# mapDashboardInstanceProviderTemplatesCreateBody
# mapDashboardInstanceProviderTemplatesCreateOutput
# mapDashboardInstanceProviderTemplatesDeleteOutput
# mapDashboardInstanceProviderTemplatesGetOutput
# mapDashboardInstanceProviderTemplatesListOutput
# mapDashboardInstanceProviderTemplatesListQuery
# mapDashboardInstanceProviderTemplatesUpdateBody
# mapDashboardInstanceProviderTemplatesUpdateOutput
# mapDashboardInstanceProvidersAuthMethodsGetOutput
# mapDashboardInstanceProvidersAuthMethodsListOutput
# mapDashboardInstanceProvidersAuthMethodsListQuery
# mapDashboardInstanceProvidersGetOutput
# mapDashboardInstanceProvidersListOutput
# mapDashboardInstanceProvidersListQuery
# mapDashboardInstanceProvidersSpecificationsGetOutput
# mapDashboardInstanceProvidersSpecificationsListOutput
# mapDashboardInstanceProvidersSpecificationsListQuery
# mapDashboardInstanceProvidersToolsGetOutput
# mapDashboardInstanceProvidersToolsListOutput
# mapDashboardInstanceProvidersToolsListQuery
# mapDashboardInstanceProvidersTriggersGetOutput
# mapDashboardInstanceProvidersTriggersListOutput
# mapDashboardInstanceProvidersTriggersListQuery
# mapDashboardInstanceProvidersVersionsGetOutput
# mapDashboardInstanceProvidersVersionsListOutput
# mapDashboardInstanceProvidersVersionsListQuery
# mapDashboardInstancePublishersGetOutput
# mapDashboardInstancePublishersListOutput
# mapDashboardInstancePublishersListQuery
# mapDashboardInstanceScmAccountsPreviewBody
# mapDashboardInstanceScmAccountsPreviewOutput
# mapDashboardInstanceScmInstallationCreateBody
# mapDashboardInstanceScmInstallationCreateOutput
# mapDashboardInstanceScmInstallationListOutput
# mapDashboardInstanceScmInstallationListQuery
# mapDashboardInstanceScmReposCreateBody
# mapDashboardInstanceScmReposCreateOutput
# mapDashboardInstanceScmReposPreviewBody
# mapDashboardInstanceScmReposPreviewOutput
# mapDashboardInstanceSessionTemplatesCreateBody
# mapDashboardInstanceSessionTemplatesCreateOutput
# mapDashboardInstanceSessionTemplatesGetOutput
# mapDashboardInstanceSessionTemplatesListOutput
# mapDashboardInstanceSessionTemplatesListQuery
# mapDashboardInstanceSessionTemplatesProvidersCreateBody
# mapDashboardInstanceSessionTemplatesProvidersCreateOutput
# mapDashboardInstanceSessionTemplatesProvidersDeleteOutput
# mapDashboardInstanceSessionTemplatesProvidersGetOutput
# mapDashboardInstanceSessionTemplatesProvidersListOutput
# mapDashboardInstanceSessionTemplatesProvidersListQuery
# mapDashboardInstanceSessionTemplatesProvidersUpdateBody
# mapDashboardInstanceSessionTemplatesProvidersUpdateOutput
# mapDashboardInstanceSessionTemplatesUpdateBody
# mapDashboardInstanceSessionTemplatesUpdateOutput
# mapDashboardInstanceSessionsConnectionsGetOutput
# mapDashboardInstanceSessionsConnectionsListOutput
# mapDashboardInstanceSessionsConnectionsListQuery
# mapDashboardInstanceSessionsCreateBody
# mapDashboardInstanceSessionsCreateOutput
# mapDashboardInstanceSessionsErrorGroupsGetOutput
# mapDashboardInstanceSessionsErrorGroupsListOutput
# mapDashboardInstanceSessionsErrorGroupsListQuery
# mapDashboardInstanceSessionsErrorsGetOutput
# mapDashboardInstanceSessionsErrorsListOutput
# mapDashboardInstanceSessionsErrorsListQuery
# mapDashboardInstanceSessionsEventsGetOutput
# mapDashboardInstanceSessionsEventsListOutput
# mapDashboardInstanceSessionsEventsListQuery
# mapDashboardInstanceSessionsGetOutput
# mapDashboardInstanceSessionsListOutput
# mapDashboardInstanceSessionsListQuery
# mapDashboardInstanceSessionsMessagesGetOutput
# mapDashboardInstanceSessionsMessagesListOutput
# mapDashboardInstanceSessionsMessagesListQuery
# mapDashboardInstanceSessionsParticipantsGetOutput
# mapDashboardInstanceSessionsParticipantsListOutput
# mapDashboardInstanceSessionsParticipantsListQuery
# mapDashboardInstanceSessionsProvidersCreateBody
# mapDashboardInstanceSessionsProvidersCreateOutput
# mapDashboardInstanceSessionsProvidersDeleteOutput
# mapDashboardInstanceSessionsProvidersGetOutput
# mapDashboardInstanceSessionsProvidersListOutput
# mapDashboardInstanceSessionsProvidersListQuery
# mapDashboardInstanceSessionsProvidersUpdateBody
# mapDashboardInstanceSessionsProvidersUpdateOutput
# mapDashboardInstanceSessionsUpdateBody
# mapDashboardInstanceSessionsUpdateOutput
# mapDashboardInstanceToolCallsCreateBody
# mapDashboardInstanceToolCallsCreateOutput
# mapDashboardInstanceToolCallsGetOutput
# mapDashboardInstanceToolCallsListOutput
# mapDashboardInstanceToolCallsListQuery
# mapDashboardOauthAuthorizationRequestsApproveBody
# mapDashboardOauthAuthorizationRequestsApproveOutput
# mapDashboardOauthAuthorizationRequestsGetOutput
# mapDashboardOauthAuthorizationRequestsRejectBody
# mapDashboardOauthAuthorizationRequestsRejectOutput
# mapDashboardOrganizationsAccessPoliciesCreateBody
# mapDashboardOrganizationsAccessPoliciesCreateOutput
# mapDashboardOrganizationsAccessPoliciesDeleteOutput
# mapDashboardOrganizationsAccessPoliciesGetOutput
# mapDashboardOrganizationsAccessPoliciesListOutput
# mapDashboardOrganizationsAccessPoliciesListQuery
# mapDashboardOrganizationsAccessPoliciesUpdateBody
# mapDashboardOrganizationsAccessPoliciesUpdateOutput
# mapDashboardOrganizationsAccessPoliciesVersionsOutput
# mapDashboardOrganizationsAccessPoliciesVersionsQuery
# mapDashboardOrganizationsAccessRolesCreateBody
# mapDashboardOrganizationsAccessRolesCreateOutput
# mapDashboardOrganizationsAccessRolesDeleteOutput
# mapDashboardOrganizationsAccessRolesGetOutput
# mapDashboardOrganizationsAccessRolesListOutput
# mapDashboardOrganizationsAccessRolesListQuery
# mapDashboardOrganizationsAccessRolesUpdateBody
# mapDashboardOrganizationsAccessRolesUpdateOutput
# mapDashboardOrganizationsAccessRolesVersionsOutput
# mapDashboardOrganizationsAccessRolesVersionsQuery
# mapDashboardOrganizationsCreateBody
# mapDashboardOrganizationsCreateOutput
# mapDashboardOrganizationsDeleteOutput
# mapDashboardOrganizationsGetOutput
# mapDashboardOrganizationsInstancesCreateBody
# mapDashboardOrganizationsInstancesCreateOutput
# mapDashboardOrganizationsInstancesDeleteOutput
# mapDashboardOrganizationsInstancesGetOutput
# mapDashboardOrganizationsInstancesListOutput
# mapDashboardOrganizationsInstancesListQuery
# mapDashboardOrganizationsInstancesUpdateBody
# mapDashboardOrganizationsInstancesUpdateOutput
# mapDashboardOrganizationsInvitesCreateBody
# mapDashboardOrganizationsInvitesCreateOutput
# mapDashboardOrganizationsInvitesDeleteOutput
# mapDashboardOrganizationsInvitesEnsureLinkOutput
# mapDashboardOrganizationsInvitesGetOutput
# mapDashboardOrganizationsInvitesListOutput
# mapDashboardOrganizationsInvitesListQuery
# mapDashboardOrganizationsInvitesUpdateBody
# mapDashboardOrganizationsInvitesUpdateOutput
# mapDashboardOrganizationsJoinAcceptBody
# mapDashboardOrganizationsJoinAcceptOutput
# mapDashboardOrganizationsJoinGetOutput
# mapDashboardOrganizationsJoinGetQuery
# mapDashboardOrganizationsJoinRejectBody
# mapDashboardOrganizationsJoinRejectOutput
# mapDashboardOrganizationsListOutput
# mapDashboardOrganizationsListQuery
# mapDashboardOrganizationsMembersDeleteOutput
# mapDashboardOrganizationsMembersGetOutput
# mapDashboardOrganizationsMembersListOutput
# mapDashboardOrganizationsMembersListQuery
# mapDashboardOrganizationsMembersPoliciesCreateBody
# mapDashboardOrganizationsMembersPoliciesCreateOutput
# mapDashboardOrganizationsMembersPoliciesDeleteOutput
# mapDashboardOrganizationsMembersUpdateBody
# mapDashboardOrganizationsMembersUpdateOutput
# mapDashboardOrganizationsOauthAppsClientSecretsCreateOutput
# mapDashboardOrganizationsOauthAppsClientSecretsDeleteOutput
# mapDashboardOrganizationsOauthAppsCreateBody
# mapDashboardOrganizationsOauthAppsCreateOutput
# mapDashboardOrganizationsOauthAppsDeleteOutput
# mapDashboardOrganizationsOauthAppsGetOutput
# mapDashboardOrganizationsOauthAppsListOutput
# mapDashboardOrganizationsOauthAppsListQuery
# mapDashboardOrganizationsOauthAppsUpdateBody
# mapDashboardOrganizationsOauthAppsUpdateOutput
# mapDashboardOrganizationsOauthAuthorizationLogsListOutput
# mapDashboardOrganizationsOauthAuthorizationLogsListQuery
# mapDashboardOrganizationsOauthAuthorizationsGetOutput
# mapDashboardOrganizationsOauthAuthorizationsListOutput
# mapDashboardOrganizationsOauthAuthorizationsListQuery
# mapDashboardOrganizationsOauthAuthorizationsRevokeOutput
# mapDashboardOrganizationsOauthCliDevicesGetOutput
# mapDashboardOrganizationsOauthCliDevicesListOutput
# mapDashboardOrganizationsOauthCliDevicesListQuery
# mapDashboardOrganizationsOauthInstallationsGetOutput
# mapDashboardOrganizationsOauthInstallationsListOutput
# mapDashboardOrganizationsOauthInstallationsListQuery
# mapDashboardOrganizationsOauthInstallationsRevokeOutput
# mapDashboardOrganizationsOauthScopesListOutput
# mapDashboardOrganizationsProjectsBrandingGetOutput
# mapDashboardOrganizationsProjectsBrandingUpdateBody
# mapDashboardOrganizationsProjectsBrandingUpdateOutput
# mapDashboardOrganizationsProjectsCreateBody
# mapDashboardOrganizationsProjectsCreateOutput
# mapDashboardOrganizationsProjectsDeleteOutput
# mapDashboardOrganizationsProjectsGetOutput
# mapDashboardOrganizationsProjectsListOutput
# mapDashboardOrganizationsProjectsListQuery
# mapDashboardOrganizationsProjectsUpdateBody
# mapDashboardOrganizationsProjectsUpdateOutput
# mapDashboardOrganizationsServiceAccountsClientSecretsCreateOutput
# mapDashboardOrganizationsServiceAccountsClientSecretsDeleteOutput
# mapDashboardOrganizationsServiceAccountsCreateBody
# mapDashboardOrganizationsServiceAccountsCreateOutput
# mapDashboardOrganizationsServiceAccountsCredentialsGetOutput
# mapDashboardOrganizationsServiceAccountsCredentialsListOutput
# mapDashboardOrganizationsServiceAccountsCredentialsListQuery
# mapDashboardOrganizationsServiceAccountsDeleteOutput
# mapDashboardOrganizationsServiceAccountsGetOutput
# mapDashboardOrganizationsServiceAccountsListOutput
# mapDashboardOrganizationsServiceAccountsListQuery
# mapDashboardOrganizationsServiceAccountsPoliciesCreateBody
# mapDashboardOrganizationsServiceAccountsPoliciesCreateOutput
# mapDashboardOrganizationsServiceAccountsPoliciesDeleteOutput
# mapDashboardOrganizationsServiceAccountsUpdateBody
# mapDashboardOrganizationsServiceAccountsUpdateOutput
# mapDashboardOrganizationsTeamsCreateBody
# mapDashboardOrganizationsTeamsCreateOutput
# mapDashboardOrganizationsTeamsGetOutput
# mapDashboardOrganizationsTeamsListOutput
# mapDashboardOrganizationsTeamsListQuery
# mapDashboardOrganizationsTeamsMembersCreateBody
# mapDashboardOrganizationsTeamsMembersCreateOutput
# mapDashboardOrganizationsTeamsMembersDeleteOutput
# mapDashboardOrganizationsTeamsPoliciesCreateBody
# mapDashboardOrganizationsTeamsPoliciesCreateOutput
# mapDashboardOrganizationsTeamsPoliciesDeleteOutput
# mapDashboardOrganizationsTeamsUpdateBody
# mapDashboardOrganizationsTeamsUpdateOutput
# mapDashboardOrganizationsUpdateBody
# mapDashboardOrganizationsUpdateOutput
# mapDashboardUsageTimelineOutput
# mapDashboardUsageTimelineQuery
# mapManagementOrganizationGetOutput
# mapManagementOrganizationUpdateBody
# mapManagementOrganizationUpdateOutput
# mapManagementUserDeleteBody
# mapManagementUserDeleteOutput
# mapManagementUserGetOutput
# mapManagementUserUpdateBody
# mapManagementUserUpdateOutput
# mapOrganizationsFlagsGetOutput
# mapOrganizationsProfileGetOutput
# mapOrganizationsProfileUpdateBody
# mapOrganizationsProfileUpdateOutput

# All types and mappers are available via:
# from .resources import *
# from .endpoints import *
